@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 .. _ex-hf-sef-data:
 
@@ -11,16 +10,17 @@ This example looks at high-frequency SEF responses.
 # Author: Jussi Nurminen (jnu@iki.fi)
 #
 # License: BSD-3-Clause
+# Copyright the MNE-Python contributors.
 
 # %%
 
 
-import mne
 import os
+
+import mne
 from mne.datasets import hf_sef
 
-fname_evoked = os.path.join(hf_sef.data_path(),
-                            'MEG/subject_b/hf_sef_15min-ave.fif')
+fname_evoked = os.path.join(hf_sef.data_path(), "MEG/subject_b/hf_sef_15min-ave.fif")
 
 print(__doc__)
 
@@ -35,7 +35,7 @@ evoked_hp.filter(l_freq=300, h_freq=None)
 
 # %%
 # Compare high-pass filtered and unfiltered data on a single channel
-ch = 'MEG0443'
+ch = "MEG0443"
 pick = evoked.ch_names.index(ch)
-edi = {'HF': evoked_hp, 'Regular': evoked}
+edi = {"HF": evoked_hp, "Regular": evoked}
 mne.viz.plot_compare_evokeds(edi, picks=pick)
