@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 .. _ex-cerebellum-source-space:
 
@@ -14,6 +13,7 @@ segmentation file.
 # Author: Alan Leggitt <alan.leggitt@ucsf.edu>
 #
 # License: BSD-3-Clause
+# Copyright the MNE-Python contributors.
 
 # %%
 
@@ -24,9 +24,9 @@ from mne.datasets import sample
 print(__doc__)
 
 data_path = sample.data_path()
-subjects_dir = data_path / 'subjects'
-subject = 'sample'
-aseg_fname = subjects_dir / 'sample' / 'mri' / 'aseg.mgz'
+subjects_dir = data_path / "subjects"
+subject = "sample"
+aseg_fname = subjects_dir / "sample" / "mri" / "aseg.mgz"
 
 # %%
 # Setup the source spaces
@@ -36,11 +36,16 @@ surf = setup_source_space(subject, subjects_dir=subjects_dir, add_dist=False)
 lh_surf = surf[0]
 
 # setup a volume source space of the left cerebellum cortex
-volume_label = 'Left-Cerebellum-Cortex'
+volume_label = "Left-Cerebellum-Cortex"
 sphere = (0, 0, 0, 0.12)
 lh_cereb = setup_volume_source_space(
-    subject, mri=aseg_fname, sphere=sphere, volume_label=volume_label,
-    subjects_dir=subjects_dir, sphere_units='m')
+    subject,
+    mri=aseg_fname,
+    sphere=sphere,
+    volume_label=volume_label,
+    subjects_dir=subjects_dir,
+    sphere_units="m",
+)
 
 # Combine the source spaces
 src = surf + lh_cereb
@@ -48,11 +53,16 @@ src = surf + lh_cereb
 # %%
 # Plot the positions of each source space
 
-fig = mne.viz.plot_alignment(subject=subject, subjects_dir=subjects_dir,
-                             surfaces='white', coord_frame='mri',
-                             src=src)
-mne.viz.set_3d_view(fig, azimuth=180, elevation=90,
-                    distance=0.30, focalpoint=(-0.03, -0.01, 0.03))
+fig = mne.viz.plot_alignment(
+    subject=subject,
+    subjects_dir=subjects_dir,
+    surfaces="white",
+    coord_frame="mri",
+    src=src,
+)
+mne.viz.set_3d_view(
+    fig, azimuth=180, elevation=90, distance=0.30, focalpoint=(-0.03, -0.01, 0.03)
+)
 
 # %%
 # You can export source positions to a NIfTI file::
