@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 .. _example-sLORETA:
 
@@ -14,6 +13,7 @@ visualisation.
 # Author: Alexandre Gramfort <alexandre.gramfort@inria.fr>
 #
 # License: BSD-3-Clause
+# Copyright the MNE-Python contributors.
 
 # %%
 
@@ -26,14 +26,13 @@ from mne.minimum_norm import apply_inverse_raw, read_inverse_operator
 print(__doc__)
 
 data_path = sample.data_path()
-fname_inv = (
-    data_path / 'MEG' / 'sample' / 'sample_audvis-meg-oct-6-meg-inv.fif')
-fname_raw = data_path / 'MEG' / 'sample' / 'sample_audvis_raw.fif'
-label_name = 'Aud-lh'
-fname_label = data_path / 'MEG' / 'sample' / 'labels' / f'{label_name}.label'
+fname_inv = data_path / "MEG" / "sample" / "sample_audvis-meg-oct-6-meg-inv.fif"
+fname_raw = data_path / "MEG" / "sample" / "sample_audvis_raw.fif"
+label_name = "Aud-lh"
+fname_label = data_path / "MEG" / "sample" / "labels" / f"{label_name}.label"
 
 snr = 1.0  # use smaller SNR for raw data
-lambda2 = 1.0 / snr ** 2
+lambda2 = 1.0 / snr**2
 method = "sLORETA"  # use sLORETA method (could also be MNE or dSPM)
 
 # Load data
@@ -41,19 +40,20 @@ raw = mne.io.read_raw_fif(fname_raw)
 inverse_operator = read_inverse_operator(fname_inv)
 label = mne.read_label(fname_label)
 
-raw.set_eeg_reference('average', projection=True)  # set average reference.
+raw.set_eeg_reference("average", projection=True)  # set average reference.
 start, stop = raw.time_as_index([0, 15])  # read the first 15s of data
 
 # Compute inverse solution
-stc = apply_inverse_raw(raw, inverse_operator, lambda2, method, label,
-                        start, stop, pick_ori=None)
+stc = apply_inverse_raw(
+    raw, inverse_operator, lambda2, method, label, start, stop, pick_ori=None
+)
 
 # Save result in stc files
-stc.save('mne_%s_raw_inverse_%s' % (method, label_name), overwrite=True)
+stc.save("mne_%s_raw_inverse_%s" % (method, label_name), overwrite=True)
 
 # %%
 # View activation time-series
 plt.plot(1e3 * stc.times, stc.data[::100, :].T)
-plt.xlabel('time (ms)')
-plt.ylabel('%s value' % method)
+plt.xlabel("time (ms)")
+plt.ylabel("%s value" % method)
 plt.show()
