@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 .. _ex-read-neo:
 
@@ -12,9 +11,12 @@ information on creating MNE-Python's data objects from NumPy arrays, see
 :ref:`tut-creating-data-structures`.
 """
 
+# License: BSD-3-Clause
+# Copyright the MNE-Python contributors.
 # %%
 
 import neo
+
 import mne
 
 # %%
@@ -23,15 +25,15 @@ import mne
 # demonstrate the steps to using NEO data. For actual data and different file
 # formats, consult the NEO documentation.
 
-reader = neo.io.ExampleIO('fakedata.nof')
+reader = neo.io.ExampleIO("fakedata.nof")
 block = reader.read(lazy=False)[0]  # get the first block
-segment = block.segments[0]         # get data from first (and only) segment
+segment = block.segments[0]  # get data from first (and only) segment
 signals = segment.analogsignals[0]  # get first (multichannel) signal
 
-data = signals.rescale('V').magnitude.T
+data = signals.rescale("V").magnitude.T
 sfreq = signals.sampling_rate.magnitude
-ch_names = [f'Neo {(idx + 1):02}' for idx in range(signals.shape[1])]
-ch_types = ['eeg'] * len(ch_names)  # if not specified, type 'misc' is assumed
+ch_names = [f"Neo {(idx + 1):02}" for idx in range(signals.shape[1])]
+ch_types = ["eeg"] * len(ch_names)  # if not specified, type 'misc' is assumed
 
 info = mne.create_info(ch_names=ch_names, ch_types=ch_types, sfreq=sfreq)
 raw = mne.io.RawArray(data, info)
