@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 .. _ex-megnoise_processing:
 
@@ -30,14 +29,16 @@ This technique is fully described and validated in :footcite:`HannaEtAl2020`
 # Authors: Jeff Hanna <jeff.hanna@gmail.com>
 #
 # License: BSD-3-Clause
+# Copyright the MNE-Python contributors.
 
 # %%
 
+import numpy as np
+
 import mne
 from mne import io
 from mne.datasets import refmeg_noise
 from mne.preprocessing import ICA
-import numpy as np
 
 print(__doc__)
 
@@ -46,7 +47,7 @@ data_path = refmeg_noise.data_path()
 # %%
 # Read raw data, cropping to 5 minutes to save memory
 
-raw_fname = data_path / 'sample_reference_MEG_noise-raw.fif'
+raw_fname = data_path / "sample_reference_MEG_noise-raw.fif"
 raw = io.read_raw_fif(raw_fname).crop(300, 600).load_data()
 
 # %%
@@ -54,27 +55,32 @@ raw = io.read_raw_fif(raw_fname).crop(300, 600).load_data()
 # been applied to these data, much of the noise in the reference channels
 # (bottom of the plot) can still be seen in the standard channels.
 select_picks = np.concatenate(
-    (mne.pick_types(raw.info, meg=True)[-32:],
-     mne.pick_types(raw.info, meg=False, ref_meg=True)))
+    (
+        mne.pick_types(raw.info, meg=True)[-32:],
+        mne.pick_types(raw.info, meg=False, ref_meg=True),
+    )
+)
 plot_kwargs = dict(
-    duration=100, order=select_picks, n_channels=len(select_picks),
-    scalings={"mag": 8e-13, "ref_meg": 2e-11})
+    duration=100,
+    order=select_picks,
+    n_channels=len(select_picks),
+    scalings={"mag": 8e-13, "ref_meg": 2e-11},
+)
 raw.plot(**plot_kwargs)
 
 # %%
 # The PSD of these data show the noise as clear peaks.
-raw.plot_psd(fmax=30)
+raw.compute_psd(fmax=30).plot(picks="data", exclude="bads")
 
 # %%
 # Run the "together" algorithm.
 raw_tog = raw.copy()
 ica_kwargs = dict(
-    method='picard',
+    method="picard",
     fit_params=dict(tol=1e-4),  # use a high tol here for speed
 )
 all_picks = mne.pick_types(raw_tog.info, meg=True, ref_meg=True)
-ica_tog = ICA(n_components=60, max_iter='auto', allow_ref_meg=True,
-              **ica_kwargs)
+ica_tog = ICA(n_components=60, max_iter="auto", allow_ref_meg=True, **ica_kwargs)
 ica_tog.fit(raw_tog, picks=all_picks)
 # low threshold (2.0) here because of cropped data, entire recording can use
 # a higher threshold (2.5)
@@ -93,7 +99,7 @@ raw_tog = ica_tog.apply(raw_tog, exclude=bad_comps)
 
 # %%
 # Cleaned data:
-raw_tog.plot_psd(fmax=30)
+raw_tog.compute_psd(fmax=30).plot(picks="data", exclude="bads")
 
 # %%
 # Now try the "separate" algorithm.
@@ -101,8 +107,7 @@ raw_sep = raw.copy()
 
 # Do ICA only on the reference channels.
 ref_picks = mne.pick_types(raw_sep.info, meg=False, ref_meg=True)
-ica_ref = ICA(n_components=2, max_iter='auto', allow_ref_meg=True,
-              **ica_kwargs)
+ica_ref = ICA(n_components=2, max_iter="auto", allow_ref_meg=True, **ica_kwargs)
 ica_ref.fit(raw_sep, picks=ref_picks)
 
 # Do ICA on both reference and standard channels. Here, we can just reuse
@@ -138,7 +143,7 @@ raw_sep.plot(**plot_kwargs)
 # %%
 # Cleaned raw data PSD:
 
-raw_sep.plot_psd(fmax=30)
+raw_sep.compute_psd(fmax=30).plot(picks="data", exclude="bads")
 
 ##############################################################################
 # References
