@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 .. _ex-sim-raw:
 
@@ -14,24 +13,30 @@ multiple times.
 #          Eric Larson <larson.eric.d@gmail.com>
 #
 # License: BSD-3-Clause
+# Copyright the MNE-Python contributors.
 
 # %%
 
-import numpy as np
 import matplotlib.pyplot as plt
+import numpy as np
 
 import mne
-from mne import find_events, Epochs, compute_covariance, make_ad_hoc_cov
+from mne import Epochs, compute_covariance, find_events, make_ad_hoc_cov
 from mne.datasets import sample
-from mne.simulation import (simulate_sparse_stc, simulate_raw,
-                            add_noise, add_ecg, add_eog)
+from mne.simulation import (
+    add_ecg,
+    add_eog,
+    add_noise,
+    simulate_raw,
+    simulate_sparse_stc,
+)
 
 print(__doc__)
 
 data_path = sample.data_path()
-meg_path = data_path / 'MEG' / 'sample'
-raw_fname = meg_path / 'sample_audvis_raw.fif'
-fwd_fname = meg_path / 'sample_audvis-meg-eeg-oct-6-fwd.fif'
+meg_path = data_path / "MEG" / "sample"
+raw_fname = meg_path / "sample_audvis_raw.fif"
+fwd_fname = meg_path / "sample_audvis-meg-eeg-oct-6-fwd.fif"
 
 # Load real data as the template
 raw = mne.io.read_raw_fif(raw_fname)
@@ -40,34 +45,36 @@ raw.set_eeg_reference(projection=True)
 ##############################################################################
 # Generate dipole time series
 n_dipoles = 4  # number of dipoles to create
-epoch_duration = 2.  # duration of each epoch/event
+epoch_duration = 2.0  # duration of each epoch/event
 n = 0  # harmonic number
 rng = np.random.RandomState(0)  # random state (make reproducible)
 
 
 def data_fun(times):
-    """Generate time-staggered sinusoids at harmonics of 10Hz"""
+    """Generate time-staggered sinusoids at harmonics of 10Hz."""
     global n
     n_samp = len(times)
     window = np.zeros(n_samp)
-    start, stop = [int(ii * float(n_samp) / (2 * n_dipoles))
-                   for ii in (2 * n, 2 * n + 1)]
-    window[start:stop] = 1.
+    start, stop = [
+        int(ii * float(n_samp) / (2 * n_dipoles)) for ii in (2 * n, 2 * n + 1)
+    ]
+    window[start:stop] = 1.0
     n += 1
-    data = 25e-9 * np.sin(2. * np.pi * 10. * n * times)
+    data = 25e-9 * np.sin(2.0 * np.pi * 10.0 * n * times)
     data *= window
     return data
 
 
-times = raw.times[:int(raw.info['sfreq'] * epoch_duration)]
+times = raw.times[: int(raw.info["sfreq"] * epoch_duration)]
 fwd = mne.read_forward_solution(fwd_fname)
-src = fwd['src']
-stc = simulate_sparse_stc(src, n_dipoles=n_dipoles, times=times,
-                          data_fun=data_fun, random_state=rng)
+src = fwd["src"]
+stc = simulate_sparse_stc(
+    src, n_dipoles=n_dipoles, times=times, data_fun=data_fun, random_state=rng
+)
 # look at our source data
 fig, ax = plt.subplots(1)
 ax.plot(times, 1e9 * stc.data.T)
-ax.set(ylabel='Amplitude (nAm)', xlabel='Time (sec)')
+ax.set(ylabel="Amplitude (nAm)", xlabel="Time (s)")
 mne.viz.utils.plt_show()
 
 ##############################################################################
@@ -83,7 +90,8 @@ raw_sim.plot()
 # Plot evoked data
 events = find_events(raw_sim)  # only 1 pos, so event number == 1
 epochs = Epochs(raw_sim, events, 1, tmin=-0.2, tmax=epoch_duration)
-cov = compute_covariance(epochs, tmax=0., method='empirical',
-                         verbose='error')  # quick calc
+cov = compute_covariance(
+    epochs, tmax=0.0, method="empirical", verbose="error"
+)  # quick calc
 evoked = epochs.average()
-evoked.plot_white(cov, time_unit='s')
+evoked.plot_white(cov, time_unit="s")
