@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 .. _ex-tfr-erds:
 
@@ -31,21 +30,22 @@ perform cluster-based permutation tests to estimate significant ERDS values
 #          Felix Klotzsche <klotzsche@cbs.mpg.de>
 #
 # License: BSD-3-Clause
+# Copyright the MNE-Python contributors.
 
 # %%
 # As usual, we import everything we need.
 
-import numpy as np
 import matplotlib.pyplot as plt
-from matplotlib.colors import TwoSlopeNorm
+import numpy as np
 import pandas as pd
 import seaborn as sns
+from matplotlib.colors import TwoSlopeNorm
+
 import mne
 from mne.datasets import eegbci
 from mne.io import concatenate_raws, read_raw_edf
-from mne.time_frequency import tfr_multitaper
 from mne.stats import permutation_cluster_1samp_test as pcluster_test
-
+from mne.time_frequency import tfr_multitaper
 
 # %%
 # First, we load and preprocess the data. We use runs 6, 10, and 14 from
@@ -53,7 +53,7 @@ from mne.stats import permutation_cluster_1samp_test as pcluster_test
 fnames = eegbci.load_data(subject=1, runs=(6, 10, 14))
 raw = concatenate_raws([read_raw_edf(f, preload=True) for f in fnames])
 
-raw.rename_channels(lambda x: x.strip('.'))  # remove dots from channel names
+raw.rename_channels(lambda x: x.strip("."))  # remove dots from channel names
 
 events, _ = mne.events_from_annotations(raw, event_id=dict(T1=2, T2=3))
 
@@ -62,8 +62,16 @@ events, _ = mne.events_from_annotations(raw, event_id=dict(T1=2, T2=3))
 tmin, tmax = -1, 4
 event_ids = dict(hands=2, feet=3)  # map event IDs to tasks
 
-epochs = mne.Epochs(raw, events, event_ids, tmin - 0.5, tmax + 0.5,
-                    picks=('C3', 'Cz', 'C4'), baseline=None, preload=True)
+epochs = mne.Epochs(
+    raw,
+    events,
+    event_ids,
+    tmin - 0.5,
+    tmax + 0.5,
+    picks=("C3", "Cz", "C4"),
+    baseline=None,
+    preload=True,
+)
 
 # %%
 # .. _cnorm-example:
@@ -81,20 +89,29 @@ vmin, vmax = -1, 1.5  # set min and max ERDS values in plot
 baseline = (-1, 0)  # baseline interval (in s)
 cnorm = TwoSlopeNorm(vmin=vmin, vcenter=0, vmax=vmax)  # min, center & max ERDS
 
-kwargs = dict(n_permutations=100, step_down_p=0.05, seed=1,
-              buffer_size=None, out_type='mask')  # for cluster test
+kwargs = dict(
+    n_permutations=100, step_down_p=0.05, seed=1, buffer_size=None, out_type="mask"
+)  # for cluster test
 
 # %%
 # Finally, we perform time/frequency decomposition over all epochs.
-tfr = tfr_multitaper(epochs, freqs=freqs, n_cycles=freqs, use_fft=True,
-                     return_itc=False, average=False, decim=2)
+tfr = tfr_multitaper(
+    epochs,
+    freqs=freqs,
+    n_cycles=freqs,
+    use_fft=True,
+    return_itc=False,
+    average=False,
+    decim=2,
+)
 tfr.crop(tmin, tmax).apply_baseline(baseline, mode="percent")
 
 for event in event_ids:
     # select desired epochs for visualization
     tfr_ev = tfr[event]
-    fig, axes = plt.subplots(1, 4, figsize=(12, 4),
-                             gridspec_kw={"width_ratios": [10, 10, 10, 1]})
+    fig, axes = plt.subplots(
+        1, 4, figsize=(12, 4), gridspec_kw={"width_ratios": [10, 10, 10, 1]}
+    )
     for ch, ax in enumerate(axes[:-1]):  # for each channel
         # positive clusters
         _, c1, p1, _ = pcluster_test(tfr_ev.data[:, ch], tail=1, **kwargs)
@@ -109,9 +126,16 @@ for event in event_ids:
         mask = c[..., p <= 0.05].any(axis=-1)
 
         # plot TFR (ERDS map with masking)
-        tfr_ev.average().plot([ch], cmap="RdBu", cnorm=cnorm, axes=ax,
-                              colorbar=False, show=False, mask=mask,
-                              mask_style="mask")
+        tfr_ev.average().plot(
+            [ch],
+            cmap="RdBu",
+            cnorm=cnorm,
+            axes=ax,
+            colorbar=False,
+            show=False,
+            mask=mask,
+            mask_style="mask",
+        )
 
         ax.set_title(epochs.ch_names[ch], fontsize=10)
         ax.axvline(0, linewidth=1, color="black", linestyle=":")  # event
@@ -140,33 +164,28 @@ df.head()
 df = tfr.to_data_frame(time_format=None, long_format=True)
 
 # Map to frequency bands:
-freq_bounds = {'_': 0,
-               'delta': 3,
-               'theta': 7,
-               'alpha': 13,
-               'beta': 35,
-               'gamma': 140}
-df['band'] = pd.cut(df['freq'], list(freq_bounds.values()),
-                    labels=list(freq_bounds)[1:])
+freq_bounds = {"_": 0, "delta": 3, "theta": 7, "alpha": 13, "beta": 35, "gamma": 140}
+df["band"] = pd.cut(
+    df["freq"], list(freq_bounds.values()), labels=list(freq_bounds)[1:]
+)
 
 # Filter to retain only relevant frequency bands:
-freq_bands_of_interest = ['delta', 'theta', 'alpha', 'beta']
+freq_bands_of_interest = ["delta", "theta", "alpha", "beta"]
 df = df[df.band.isin(freq_bands_of_interest)]
-df['band'] = df['band'].cat.remove_unused_categories()
+df["band"] = df["band"].cat.remove_unused_categories()
 
 # Order channels for plotting:
-df['channel'] = df['channel'].cat.reorder_categories(('C3', 'Cz', 'C4'),
-                                                     ordered=True)
+df["channel"] = df["channel"].cat.reorder_categories(("C3", "Cz", "C4"), ordered=True)
 
-g = sns.FacetGrid(df, row='band', col='channel', margin_titles=True)
-g.map(sns.lineplot, 'time', 'value', 'condition', n_boot=10)
-axline_kw = dict(color='black', linestyle='dashed', linewidth=0.5, alpha=0.5)
+g = sns.FacetGrid(df, row="band", col="channel", margin_titles=True)
+g.map(sns.lineplot, "time", "value", "condition", n_boot=10)
+axline_kw = dict(color="black", linestyle="dashed", linewidth=0.5, alpha=0.5)
 g.map(plt.axhline, y=0, **axline_kw)
 g.map(plt.axvline, x=0, **axline_kw)
 g.set(ylim=(None, 1.5))
-g.set_axis_labels("Time (s)", "ERDS (%)")
+g.set_axis_labels("Time (s)", "ERDS")
 g.set_titles(col_template="{col_name}", row_template="{row_name}")
-g.add_legend(ncol=2, loc='lower center')
+g.add_legend(ncol=2, loc="lower center")
 g.fig.subplots_adjust(left=0.1, right=0.9, top=0.9, bottom=0.08)
 
 # %%
@@ -175,20 +194,30 @@ g.fig.subplots_adjust(left=0.1, right=0.9, top=0.9, bottom=0.08)
 # Here, we use seaborn to plot the average ERDS in the motor imagery interval
 # as a function of frequency band and imagery condition:
 
-df_mean = (df.query('time > 1')
-             .groupby(['condition', 'epoch', 'band', 'channel'])[['value']]
-             .mean()
-             .reset_index())
+df_mean = (
+    df.query("time > 1")
+    .groupby(["condition", "epoch", "band", "channel"], observed=False)[["value"]]
+    .mean()
+    .reset_index()
+)
 
-g = sns.FacetGrid(df_mean, col='condition', col_order=['hands', 'feet'],
-                  margin_titles=True)
-g = (g.map(sns.violinplot, 'channel', 'value', 'band', n_boot=10,
-           palette='deep', order=['C3', 'Cz', 'C4'],
-           hue_order=freq_bands_of_interest,
-           linewidth=0.5).add_legend(ncol=4, loc='lower center'))
+g = sns.FacetGrid(
+    df_mean, col="condition", col_order=["hands", "feet"], margin_titles=True
+)
+g = g.map(
+    sns.violinplot,
+    "channel",
+    "value",
+    "band",
+    cut=0,
+    palette="deep",
+    order=["C3", "Cz", "C4"],
+    hue_order=freq_bands_of_interest,
+    linewidth=0.5,
+).add_legend(ncol=4, loc="lower center")
 
 g.map(plt.axhline, **axline_kw)
-g.set_axis_labels("", "ERDS (%)")
+g.set_axis_labels("", "ERDS")
 g.set_titles(col_template="{col_name}", row_template="{row_name}")
 g.fig.subplots_adjust(left=0.1, right=0.9, top=0.9, bottom=0.3)
 
