@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 .. _ex-evoked-whitening:
 
@@ -21,14 +20,14 @@ References
 #          Denis A. Engemann <denis.engemann@gmail.com>
 #
 # License: BSD-3-Clause
+# Copyright the MNE-Python contributors.
 
 # %%
 
 import mne
-
 from mne import io
-from mne.datasets import sample
 from mne.cov import compute_covariance
+from mne.datasets import sample
 
 print(__doc__)
 
@@ -36,21 +35,30 @@ print(__doc__)
 # Set parameters
 
 data_path = sample.data_path()
-meg_path = data_path / 'MEG' / 'sample'
-raw_fname = meg_path / 'sample_audvis_filt-0-40_raw.fif'
-event_fname = meg_path / 'sample_audvis_filt-0-40_raw-eve.fif'
+meg_path = data_path / "MEG" / "sample"
+raw_fname = meg_path / "sample_audvis_filt-0-40_raw.fif"
+event_fname = meg_path / "sample_audvis_filt-0-40_raw-eve.fif"
 
 raw = io.read_raw_fif(raw_fname, preload=True)
-raw.filter(1, 40, fir_design='firwin')
-raw.info['bads'] += ['MEG 2443']  # bads + 1 more
+raw.filter(1, 40, fir_design="firwin")
+raw.info["bads"] += ["MEG 2443"]  # bads + 1 more
 events = mne.read_events(event_fname)
 
 # let's look at rare events, button presses
 event_id, tmin, tmax = 2, -0.2, 0.5
 reject = dict(mag=4e-12, grad=4000e-13, eeg=80e-6)
 
-epochs = mne.Epochs(raw, events, event_id, tmin, tmax, picks=('meg', 'eeg'),
-                    baseline=None, reject=reject, preload=True)
+epochs = mne.Epochs(
+    raw,
+    events,
+    event_id,
+    tmin,
+    tmax,
+    picks=("meg", "eeg"),
+    baseline=None,
+    reject=reject,
+    preload=True,
+)
 
 # Uncomment next line to use fewer samples and study regularization effects
 # epochs = epochs[:20]  # For your data, use as many samples as you can!
@@ -58,24 +66,32 @@ epochs = mne.Epochs(raw, events, event_id, tmin, tmax, picks=('meg', 'eeg'),
 # %%
 # Compute covariance using automated regularization
 method_params = dict(diagonal_fixed=dict(mag=0.01, grad=0.01, eeg=0.01))
-noise_covs = compute_covariance(epochs, tmin=None, tmax=0, method='auto',
-                                return_estimators=True, n_jobs=None,
-                                projs=None, rank=None,
-                                method_params=method_params, verbose=True)
+noise_covs = compute_covariance(
+    epochs,
+    tmin=None,
+    tmax=0,
+    method="auto",
+    return_estimators=True,
+    n_jobs=None,
+    projs=None,
+    rank=None,
+    method_params=method_params,
+    verbose=True,
+)
 
 # With "return_estimator=True" all estimated covariances sorted
 # by log-likelihood are returned.
 
-print('Covariance estimates sorted from best to worst')
+print("Covariance estimates sorted from best to worst")
 for c in noise_covs:
-    print("%s : %s" % (c['method'], c['loglik']))
+    print("%s : %s" % (c["method"], c["loglik"]))
 
 # %%
 # Show the evoked data:
 
 evoked = epochs.average()
 
-evoked.plot(time_unit='s')  # plot evoked response
+evoked.plot(time_unit="s")  # plot evoked response
 
 # %%
 # We can then show whitening for our various noise covariance estimates.
@@ -86,4 +102,4 @@ evoked.plot(time_unit='s')  # plot evoked response
 #
 # For the Global field power we expect a value of 1.
 
-evoked.plot_white(noise_covs, time_unit='s')
+evoked.plot_white(noise_covs, time_unit="s")
