@@ -10,6 +10,8 @@ Examples
 """
 
 # Authors : Eric Larson, PhD
+# License: BSD-3-Clause
+# Copyright the MNE-Python contributors.
 
 import mne
 
@@ -17,7 +19,8 @@ import mne
 def run():
     """Run command."""
     from mne.commands.utils import get_optparser
-    parser = get_optparser(__file__, usage='usage: %prog fname [fname2 ...]')
+
+    parser = get_optparser(__file__, usage="usage: %prog fname [fname2 ...]")
     options, args = parser.parse_args()
     for arg in args:
         print(mne.what(arg))
