@@ -1,14 +1,19 @@
 # Authors: Mainak Jas <mainak.jas@telecom-paristech.fr>
 #
 # License: BSD-3-Clause
+# Copyright the MNE-Python contributors.
 from functools import partial
 
-from ...utils import verbose, get_config
-from ..utils import (has_dataset, _get_version, _version_doc,
-                     _data_path_doc_accept, _download_mne_dataset)
+from ...utils import get_config, verbose
+from ..utils import (
+    _data_path_doc_accept,
+    _download_mne_dataset,
+    _get_version,
+    _version_doc,
+    has_dataset,
+)
 
-
-has_brainstorm_data = partial(has_dataset, name='bst_raw')
+has_brainstorm_data = partial(has_dataset, name="bst_raw")
 
 _description = """
 URL: http://neuroimage.usc.edu/brainstorm/DatasetMedianNerveCtf
@@ -26,26 +31,40 @@ URL: http://neuroimage.usc.edu/brainstorm/DatasetMedianNerveCtf
 
 
 @verbose
-def data_path(path=None, force_update=False, update_path=True,
-              download=True, accept=False, *, verbose=None):    # noqa: D103
+def data_path(
+    path=None,
+    force_update=False,
+    update_path=True,
+    download=True,
+    accept=False,
+    *,
+    verbose=None,
+):  # noqa: D103
     return _download_mne_dataset(
-        name='bst_raw', processor='nested_untar', path=path,
-        force_update=force_update, update_path=update_path,
-        download=download, accept=accept)
+        name="bst_raw",
+        processor="nested_untar",
+        path=path,
+        force_update=force_update,
+        update_path=update_path,
+        download=download,
+        accept=accept,
+    )
 
 
 _data_path_doc = _data_path_doc_accept.format(
-    name='brainstorm', conf='MNE_DATASETS_BRAINSTORM_DATA_PATH')
-_data_path_doc = _data_path_doc.replace('brainstorm dataset',
-                                        'brainstorm (bst_raw) dataset')
+    name="brainstorm", conf="MNE_DATASETS_BRAINSTORM_DATA_PATH"
+)
+_data_path_doc = _data_path_doc.replace(
+    "brainstorm dataset", "brainstorm (bst_raw) dataset"
+)
 data_path.__doc__ = _data_path_doc
 
 
 def get_version():  # noqa: D103
-    return _get_version('bst_raw')
+    return _get_version("bst_raw")
 
 
-get_version.__doc__ = _version_doc.format(name='brainstorm')
+get_version.__doc__ = _version_doc.format(name="brainstorm")
 
 
 def description():  # noqa: D103
@@ -55,8 +74,7 @@ def description():  # noqa: D103
 
 
 def _skip_bstraw_data():
-    skip_testing = (get_config('MNE_SKIP_TESTING_DATASET_TESTS', 'false') ==
-                    'true')
+    skip_testing = get_config("MNE_SKIP_TESTING_DATASET_TESTS", "false") == "true"
     skip = skip_testing or not has_brainstorm_data()
     return skip
 
@@ -64,5 +82,7 @@ def _skip_bstraw_data():
 def requires_bstraw_data(func):
     """Skip testing data test."""
     import pytest
-    return pytest.mark.skipif(_skip_bstraw_data(),
-                              reason='Requires brainstorm dataset')(func)
+
+    return pytest.mark.skipif(
+        _skip_bstraw_data(), reason="Requires brainstorm dataset"
+    )(func)
