@@ -5,13 +5,16 @@
 #          Jean-Remi King <jeanremi.king@gmail.com>
 #
 # License: BSD-3-Clause
+# Copyright the MNE-Python contributors.
 
-import numpy as np
 import datetime as dt
 import numbers
+
+import numpy as np
+
+from ..fixes import BaseEstimator, _check_fit_params, _get_check_scoring
 from ..parallel import parallel_func
-from ..fixes import BaseEstimator, is_classifier, _get_check_scoring
-from ..utils import warn, verbose
+from ..utils import verbose, warn
 
 
 class LinearModel(BaseEstimator):
@@ -51,13 +54,37 @@ class LinearModel(BaseEstimator):
     .. footbibliography::
     """
 
+    _model_attr_wrap = (
+        "transform",
+        "predict",
+        "predict_proba",
+        "_estimator_type",
+        "decision_function",
+        "score",
+        "classes_",
+    )
+
     def __init__(self, model=None):  # noqa: D102
         if model is None:
             from sklearn.linear_model import LogisticRegression
-            model = LogisticRegression(solver='liblinear')
+
+            model = LogisticRegression(solver="liblinear")
 
         self.model = model
-        self._estimator_type = getattr(model, "_estimator_type", None)
+
+    def _more_tags(self):
+        return {"no_validation": True}
+
+    def __getattr__(self, attr):
+        """Wrap to model for some attributes."""
+        if attr in LinearModel._model_attr_wrap:
+            return getattr(self.model, attr)
+        elif attr == "fit_transform" and hasattr(self.model, "fit_transform"):
+            return super().__getattr__(self, "_fit_transform")
+        return super().__getattr__(self, attr)
+
+    def _fit_transform(self, X, y):
+        return self.fit(X, y).transform(X)
 
     def fit(self, X, y, **fit_params):
         """Estimate the coefficients of the linear model.
@@ -81,18 +108,22 @@ class LinearModel(BaseEstimator):
         """
         X, y = np.asarray(X), np.asarray(y)
         if X.ndim != 2:
-            raise ValueError('LinearModel only accepts 2-dimensional X, got '
-                             '%s instead.' % (X.shape,))
+            raise ValueError(
+                "LinearModel only accepts 2-dimensional X, got "
+                "%s instead." % (X.shape,)
+            )
         if y.ndim > 2:
-            raise ValueError('LinearModel only accepts up to 2-dimensional y, '
-                             'got %s instead.' % (y.shape,))
+            raise ValueError(
+                "LinearModel only accepts up to 2-dimensional y, "
+                "got %s instead." % (y.shape,)
+            )
 
         # fit the Model
         self.model.fit(X, y, **fit_params)
 
         # Computes patterns using Haufe's trick: A = Cov_X . W . Precision_Y
 
-        inv_Y = 1.
+        inv_Y = 1.0
         X = X - X.mean(0, keepdims=True)
         if y.ndim == 2 and y.shape[1] != 1:
             y = y - y.mean(0, keepdims=True)
@@ -103,170 +134,80 @@ class LinearModel(BaseEstimator):
 
     @property
     def filters_(self):
-        if hasattr(self.model, 'coef_'):
+        if hasattr(self.model, "coef_"):
             # Standard Linear Model
             filters = self.model.coef_
-        elif hasattr(self.model.best_estimator_, 'coef_'):
+        elif hasattr(self.model.best_estimator_, "coef_"):
             # Linear Model with GridSearchCV
             filters = self.model.best_estimator_.coef_
         else:
-            raise ValueError('model does not have a `coef_` attribute.')
+            raise ValueError("model does not have a `coef_` attribute.")
         if filters.ndim == 2 and filters.shape[0] == 1:
             filters = filters[0]
         return filters
 
-    def transform(self, X):
-        """Transform the data using the linear model.
-
-        Parameters
-        ----------
-        X : array, shape (n_samples, n_features)
-            The data to transform.
-
-        Returns
-        -------
-        y_pred : array, shape (n_samples,)
-            The predicted targets.
-        """
-        return self.model.transform(X)
-
-    def fit_transform(self, X, y):
-        """Fit the data and transform it using the linear model.
-
-        Parameters
-        ----------
-        X : array, shape (n_samples, n_features)
-            The training input samples to estimate the linear coefficients.
-        y : array, shape (n_samples,)
-            The target values.
-
-        Returns
-        -------
-        y_pred : array, shape (n_samples,)
-            The predicted targets.
-        """
-        return self.fit(X, y).transform(X)
-
-    def predict(self, X):
-        """Compute predictions of y from X.
-
-        Parameters
-        ----------
-        X : array, shape (n_samples, n_features)
-            The data used to compute the predictions.
-
-        Returns
-        -------
-        y_pred : array, shape (n_samples,)
-            The predictions.
-        """
-        return self.model.predict(X)
-
-    def predict_proba(self, X):
-        """Compute probabilistic predictions of y from X.
-
-        Parameters
-        ----------
-        X : array, shape (n_samples, n_features)
-            The data used to compute the predictions.
-
-        Returns
-        -------
-        y_pred : array, shape (n_samples, n_classes)
-            The probabilities.
-        """
-        return self.model.predict_proba(X)
-
-    def decision_function(self, X):
-        """Compute distance from the decision function of y from X.
-
-        Parameters
-        ----------
-        X : array, shape (n_samples, n_features)
-            The data used to compute the predictions.
-
-        Returns
-        -------
-        y_pred : array, shape (n_samples, n_classes)
-            The distances.
-        """
-        return self.model.decision_function(X)
-
-    def score(self, X, y):
-        """Score the linear model computed on the given test data.
-
-        Parameters
-        ----------
-        X : array, shape (n_samples, n_features)
-            The data to transform.
-        y : array, shape (n_samples,)
-            The target values.
-
-        Returns
-        -------
-        score : float
-            Score of the linear model.
-        """
-        return self.model.score(X, y)
-
 
 def _set_cv(cv, estimator=None, X=None, y=None):
     """Set the default CV depending on whether clf is classifier/regressor."""
     # Detect whether classification or regression
-    if estimator in ['classifier', 'regressor']:
-        est_is_classifier = estimator == 'classifier'
+    from sklearn.base import is_classifier
+
+    if estimator in ["classifier", "regressor"]:
+        est_is_classifier = estimator == "classifier"
     else:
         est_is_classifier = is_classifier(estimator)
     # Setup CV
     from sklearn import model_selection as models
-    from sklearn.model_selection import (check_cv, StratifiedKFold, KFold)
+    from sklearn.model_selection import KFold, StratifiedKFold, check_cv
+
     if isinstance(cv, (int, np.int64)):
         XFold = StratifiedKFold if est_is_classifier else KFold
         cv = XFold(n_splits=cv)
     elif isinstance(cv, str):
         if not hasattr(models, cv):
-            raise ValueError('Unknown cross-validation')
+            raise ValueError("Unknown cross-validation")
         cv = getattr(models, cv)
         cv = cv()
     cv = check_cv(cv=cv, y=y, classifier=est_is_classifier)
 
     # Extract train and test set to retrieve them at predict time
-    cv_splits = [(train, test) for train, test in
-                 cv.split(X=np.zeros_like(y), y=y)]
+    cv_splits = [(train, test) for train, test in cv.split(X=np.zeros_like(y), y=y)]
 
     if not np.all([len(train) for train, _ in cv_splits]):
-        raise ValueError('Some folds do not have any train epochs.')
+        raise ValueError("Some folds do not have any train epochs.")
 
     return cv, cv_splits
 
 
 def _check_estimator(estimator, get_params=True):
     """Check whether an object has the methods required by sklearn."""
-    valid_methods = ('predict', 'transform', 'predict_proba',
-                     'decision_function')
-    if (
-        (not hasattr(estimator, 'fit')) or
-        (not any(hasattr(estimator, method) for method in valid_methods))
+    valid_methods = ("predict", "transform", "predict_proba", "decision_function")
+    if (not hasattr(estimator, "fit")) or (
+        not any(hasattr(estimator, method) for method in valid_methods)
     ):
-        raise ValueError('estimator must be a scikit-learn transformer or '
-                         'an estimator with the fit and a predict-like (e.g. '
-                         'predict_proba) or a transform method.')
+        raise ValueError(
+            "estimator must be a scikit-learn transformer or "
+            "an estimator with the fit and a predict-like (e.g. "
+            "predict_proba) or a transform method."
+        )
 
-    if get_params and not hasattr(estimator, 'get_params'):
-        raise ValueError('estimator must be a scikit-learn transformer or an '
-                         'estimator with the get_params method that allows '
-                         'cloning.')
+    if get_params and not hasattr(estimator, "get_params"):
+        raise ValueError(
+            "estimator must be a scikit-learn transformer or an "
+            "estimator with the get_params method that allows "
+            "cloning."
+        )
 
 
 def _get_inverse_funcs(estimator, terminal=True):
     """Retrieve the inverse functions of an pipeline or an estimator."""
     inverse_func = [False]
-    if hasattr(estimator, 'steps'):
+    if hasattr(estimator, "steps"):
         # if pipeline, retrieve all steps by nesting
         inverse_func = list()
         for _, est in estimator.steps:
             inverse_func.extend(_get_inverse_funcs(est, terminal=False))
-    elif hasattr(estimator, 'inverse_transform'):
+    elif hasattr(estimator, "inverse_transform"):
         # if not pipeline attempt to retrieve inverse function
         inverse_func = [estimator.inverse_transform]
 
@@ -284,7 +225,7 @@ def _get_inverse_funcs(estimator, terminal=True):
     return inverse_func
 
 
-def get_coef(estimator, attr='filters_', inverse_transform=False):
+def get_coef(estimator, attr="filters_", inverse_transform=False):
     """Retrieve the coefficients of an estimator ending with a Linear Model.
 
     This is typically useful to retrieve "spatial filters" or "spatial
@@ -312,13 +253,13 @@ def get_coef(estimator, attr='filters_', inverse_transform=False):
     """
     # Get the coefficients of the last estimator in case of nested pipeline
     est = estimator
-    while hasattr(est, 'steps'):
+    while hasattr(est, "steps"):
         est = est.steps[-1][1]
 
     squeeze_first_dim = False
 
     # If SlidingEstimator, loop across estimators
-    if hasattr(est, 'estimators_'):
+    if hasattr(est, "estimators_"):
         coef = list()
         for this_est in est.estimators_:
             coef.append(get_coef(this_est, attr, inverse_transform))
@@ -326,8 +267,9 @@ def get_coef(estimator, attr='filters_', inverse_transform=False):
         coef = coef[np.newaxis]  # fake a sample dimension
         squeeze_first_dim = True
     elif not hasattr(est, attr):
-        raise ValueError('This estimator does not have a %s attribute:\n%s'
-                         % (attr, est))
+        raise ValueError(
+            "This estimator does not have a %s attribute:\n%s" % (attr, est)
+        )
     else:
         coef = getattr(est, attr)
 
@@ -337,9 +279,10 @@ def get_coef(estimator, attr='filters_', inverse_transform=False):
 
     # inverse pattern e.g. to get back physical units
     if inverse_transform:
-        if not hasattr(estimator, 'steps') and not hasattr(est, 'estimators_'):
-            raise ValueError('inverse_transform can only be applied onto '
-                             'pipeline estimators.')
+        if not hasattr(estimator, "steps") and not hasattr(est, "estimators_"):
+            raise ValueError(
+                "inverse_transform can only be applied onto " "pipeline estimators."
+            )
         # The inverse_transform parameter will call this method on any
         # estimator contained in the pipeline, in reverse order.
         for inverse_func in _get_inverse_funcs(estimator)[::-1]:
@@ -352,9 +295,18 @@ def get_coef(estimator, attr='filters_', inverse_transform=False):
 
 
 @verbose
-def cross_val_multiscore(estimator, X, y=None, groups=None, scoring=None,
-                         cv=None, n_jobs=None, verbose=None, fit_params=None,
-                         pre_dispatch='2*n_jobs'):
+def cross_val_multiscore(
+    estimator,
+    X,
+    y=None,
+    groups=None,
+    scoring=None,
+    cv=None,
+    n_jobs=None,
+    verbose=None,
+    fit_params=None,
+    pre_dispatch="2*n_jobs",
+):
     """Evaluate a score by cross-validation.
 
     Parameters
@@ -416,10 +368,10 @@ def cross_val_multiscore(estimator, X, y=None, groups=None, scoring=None,
         Array of scores of the estimator for each run of the cross validation.
     """
     # This code is copied from sklearn
-
-    from sklearn.base import clone
-    from sklearn.utils import indexable
+    from sklearn.base import clone, is_classifier
     from sklearn.model_selection._split import check_cv
+    from sklearn.utils import indexable
+
     check_scoring = _get_check_scoring()
 
     X, y, groups = indexable(X, y, groups)
@@ -430,15 +382,23 @@ def cross_val_multiscore(estimator, X, y=None, groups=None, scoring=None,
     # We clone the estimator to make sure that all the folds are
     # independent, and that it is pickle-able.
     # Note: this parallelization is implemented using MNE Parallel
-    parallel, p_func, n_jobs = parallel_func(_fit_and_score, n_jobs,
-                                             pre_dispatch=pre_dispatch)
-    position = hasattr(estimator, 'position')
+    parallel, p_func, n_jobs = parallel_func(
+        _fit_and_score, n_jobs, pre_dispatch=pre_dispatch
+    )
+    position = hasattr(estimator, "position")
     scores = parallel(
         p_func(
-            estimator=clone(estimator), X=X, y=y, scorer=scorer, train=train,
-            test=test, fit_params=fit_params, verbose=verbose,
+            estimator=clone(estimator),
+            X=X,
+            y=y,
+            scorer=scorer,
+            train=train,
+            test=test,
+            fit_params=fit_params,
+            verbose=verbose,
             parameters=dict(position=ii % n_jobs) if position else None,
-        ) for ii, (train, test) in enumerate(cv_iter)
+        )
+        for ii, (train, test) in enumerate(cv_iter)
     )
     return np.array(scores)[:, 0, ...]  # flatten over joblib output.
 
@@ -446,14 +406,26 @@ def cross_val_multiscore(estimator, X, y=None, groups=None, scoring=None,
 # This verbose is necessary to properly set the verbosity level
 # during parallelization
 @verbose
-def _fit_and_score(estimator, X, y, scorer, train, test,
-                   parameters, fit_params, return_train_score=False,
-                   return_parameters=False, return_n_test_samples=False,
-                   return_times=False, error_score='raise', *, verbose=None,
-                   position=0):
+def _fit_and_score(
+    estimator,
+    X,
+    y,
+    scorer,
+    train,
+    test,
+    parameters,
+    fit_params,
+    return_train_score=False,
+    return_parameters=False,
+    return_n_test_samples=False,
+    return_times=False,
+    error_score="raise",
+    *,
+    verbose=None,
+    position=0,
+):
     """Fit estimator and compute scores for a given dataset split."""
     #  This code is adapted from sklearn
-    from ..fixes import _check_fit_params
     from sklearn.utils.metaestimators import _safe_split
     from sklearn.utils.validation import _num_samples
 
@@ -479,19 +451,23 @@ def _fit_and_score(estimator, X, y, scorer, train, test,
         # Note fit time as time until error
         fit_duration = dt.datetime.now() - start_time
         score_duration = dt.timedelta(0)
-        if error_score == 'raise':
+        if error_score == "raise":
             raise
         elif isinstance(error_score, numbers.Number):
             test_score = error_score
             if return_train_score:
                 train_score = error_score
-            warn("Classifier fit failed. The score on this train-test"
-                 " partition for these parameters will be set to %f. "
-                 "Details: \n%r" % (error_score, e))
+            warn(
+                "Classifier fit failed. The score on this train-test"
+                " partition for these parameters will be set to %f. "
+                "Details: \n%r" % (error_score, e)
+            )
         else:
-            raise ValueError("error_score must be the string 'raise' or a"
-                             " numeric value. (Hint: if using 'raise', please"
-                             " make sure that it has been spelled correctly.)")
+            raise ValueError(
+                "error_score must be the string 'raise' or a"
+                " numeric value. (Hint: if using 'raise', please"
+                " make sure that it has been spelled correctly.)"
+            )
 
     else:
         fit_duration = dt.datetime.now() - start_time
@@ -505,10 +481,7 @@ def _fit_and_score(estimator, X, y, scorer, train, test,
     if return_n_test_samples:
         ret.append(_num_samples(X_test))
     if return_times:
-        ret.extend([
-            fit_duration.total_seconds(),
-            score_duration.total_seconds()
-        ])
+        ret.extend([fit_duration.total_seconds(), score_duration.total_seconds()])
     if return_parameters:
         ret.append(parameters)
     return ret
@@ -524,7 +497,7 @@ def _score(estimator, X_test, y_test, scorer):
         score = scorer(estimator, X_test)
     else:
         score = scorer(estimator, X_test, y_test)
-    if hasattr(score, 'item'):
+    if hasattr(score, "item"):
         try:
             # e.g. unwrap memmapped scalars
             score = score.item()
