@@ -1,31 +1,32 @@
 # Author: Jean-Remi King, <jeanremi.king@gmail.com>
 #
 # License: BSD-3-Clause
+# Copyright the MNE-Python contributors.
 
 
 import numpy as np
-from numpy.testing import assert_array_equal
 import pytest
+from numpy.testing import assert_array_equal
 
-from mne.utils import requires_sklearn
 from mne.decoding.time_frequency import TimeFrequency
 
 
-@requires_sklearn
 def test_timefrequency():
     """Test TimeFrequency."""
+    pytest.importorskip("sklearn")
     from sklearn.base import clone
+
     # Init
     n_freqs = 3
     freqs = [20, 21, 22]
     tf = TimeFrequency(freqs, sfreq=100)
-    for output in ['avg_power', 'foo', None]:
+    for output in ["avg_power", "foo", None]:
         pytest.raises(ValueError, TimeFrequency, freqs, output=output)
     tf = clone(tf)
 
     # Clone estimator
     freqs_array = np.array(np.asarray(freqs))
-    tf = TimeFrequency(freqs_array, 100, "morlet", freqs_array / 5.)
+    tf = TimeFrequency(freqs_array, 100, "morlet", freqs_array / 5.0)
     clone(tf)
 
     # Fit
