@@ -1,25 +1,28 @@
-# -*- coding: utf-8 -*-
 # Authors: Mainak Jas <mainak@neuro.hut.fi>
 #          Alexandre Gramfort <alexandre.gramfort@inria.fr>
 #          Romain Trachel <trachelr@gmail.com>
 #
 # License: BSD-3-Clause
+# Copyright the MNE-Python contributors.
 
 import numpy as np
 
-from .mixin import TransformerMixin
-from .base import BaseEstimator
-
-from .. import pick_types
+from .._fiff.pick import (
+    _pick_data_channels,
+    _picks_by_type,
+    _picks_to_idx,
+    pick_info,
+    pick_types,
+)
+from ..cov import _check_scalings_user
 from ..filter import filter_data
 from ..time_frequency import psd_array_multitaper
-from ..utils import fill_doc, _check_option, _validate_type, verbose
-from ..io.pick import (pick_info, _pick_data_channels, _picks_by_type,
-                       _picks_to_idx)
-from ..cov import _check_scalings_user
+from ..utils import _check_option, _validate_type, fill_doc, verbose
+from .base import BaseEstimator
+from .mixin import TransformerMixin
 
 
-class _ConstantScaler():
+class _ConstantScaler:
     """Scale channel types using constant values."""
 
     def __init__(self, info, scalings, do_scaling=True):
@@ -29,15 +32,17 @@ class _ConstantScaler():
 
     def fit(self, X, y=None):
         scalings = _check_scalings_user(self._scalings)
-        picks_by_type = _picks_by_type(pick_info(
-            self._info, _pick_data_channels(self._info, exclude=())))
+        picks_by_type = _picks_by_type(
+            pick_info(self._info, _pick_data_channels(self._info, exclude=()))
+        )
         std = np.ones(sum(len(p[1]) for p in picks_by_type))
         if X.shape[1] != len(std):
-            raise ValueError('info had %d data channels but X has %d channels'
-                             % (len(std), len(X)))
+            raise ValueError(
+                "info had %d data channels but X has %d channels" % (len(std), len(X))
+            )
         if self._do_scaling:  # this is silly, but necessary for completeness
             for kind, picks in picks_by_type:
-                std[picks] = 1. / scalings[kind]
+                std[picks] = 1.0 / scalings[kind]
         self.std_ = std
         self.mean_ = np.zeros_like(std)
         return self
@@ -67,7 +72,7 @@ def _sklearn_reshape_apply(func, return_result, X, *args, **kwargs):
 
 @fill_doc
 class Scaler(TransformerMixin, BaseEstimator):
-    u"""Standardize channel data.
+    """Standardize channel data.
 
     This class scales data for each channel. It differs from scikit-learn
     classes (e.g., :class:`sklearn.preprocessing.StandardScaler`) in that
@@ -102,31 +107,38 @@ class Scaler(TransformerMixin, BaseEstimator):
         if ``scalings`` is a dict or None).
     """
 
-    def __init__(self, info=None, scalings=None, with_mean=True,
-                 with_std=True):  # noqa: D102
+    def __init__(
+        self, info=None, scalings=None, with_mean=True, with_std=True
+    ):  # noqa: D102
         self.info = info
         self.with_mean = with_mean
         self.with_std = with_std
         self.scalings = scalings
 
         if not (scalings is None or isinstance(scalings, (dict, str))):
-            raise ValueError('scalings type should be dict, str, or None, '
-                             'got %s' % type(scalings))
+            raise ValueError(
+                "scalings type should be dict, str, or None, " "got %s" % type(scalings)
+            )
         if isinstance(scalings, str):
-            _check_option('scalings', scalings, ['mean', 'median'])
+            _check_option("scalings", scalings, ["mean", "median"])
         if scalings is None or isinstance(scalings, dict):
             if info is None:
-                raise ValueError('Need to specify "info" if scalings is'
-                                 '%s' % type(scalings))
+                raise ValueError(
+                    'Need to specify "info" if scalings is' "%s" % type(scalings)
+                )
             self._scaler = _ConstantScaler(info, scalings, self.with_std)
-        elif scalings == 'mean':
+        elif scalings == "mean":
             from sklearn.preprocessing import StandardScaler
+
             self._scaler = StandardScaler(
-                with_mean=self.with_mean, with_std=self.with_std)
+                with_mean=self.with_mean, with_std=self.with_std
+            )
         else:  # scalings == 'median':
             from sklearn.preprocessing import RobustScaler
+
             self._scaler = RobustScaler(
-                with_centering=self.with_mean, with_scaling=self.with_std)
+                with_centering=self.with_mean, with_scaling=self.with_std
+            )
 
     def fit(self, epochs_data, y=None):
         """Standardize data across channels.
@@ -143,7 +155,7 @@ class Scaler(TransformerMixin, BaseEstimator):
         self : instance of Scaler
             The modified instance.
         """
-        _validate_type(epochs_data, np.ndarray, 'epochs_data')
+        _validate_type(epochs_data, np.ndarray, "epochs_data")
         if epochs_data.ndim == 2:
             epochs_data = epochs_data[..., np.newaxis]
         assert epochs_data.ndim == 3, epochs_data.shape
@@ -168,14 +180,13 @@ class Scaler(TransformerMixin, BaseEstimator):
         This function makes a copy of the data before the operations and the
         memory usage may be large with big data.
         """
-        _validate_type(epochs_data, np.ndarray, 'epochs_data')
+        _validate_type(epochs_data, np.ndarray, "epochs_data")
         if epochs_data.ndim == 2:  # can happen with SlidingEstimator
             if self.info is not None:
-                assert len(self.info['ch_names']) == epochs_data.shape[1]
+                assert len(self.info["ch_names"]) == epochs_data.shape[1]
             epochs_data = epochs_data[..., np.newaxis]
         assert epochs_data.ndim == 3, epochs_data.shape
-        return _sklearn_reshape_apply(self._scaler.transform, True,
-                                      epochs_data)
+        return _sklearn_reshape_apply(self._scaler.transform, True, epochs_data)
 
     def fit_transform(self, epochs_data, y=None):
         """Fit to data, then transform it.
@@ -222,8 +233,7 @@ class Scaler(TransformerMixin, BaseEstimator):
         memory usage may be large with big data.
         """
         assert epochs_data.ndim == 3, epochs_data.shape
-        return _sklearn_reshape_apply(self._scaler.inverse_transform, True,
-                                      epochs_data)
+        return _sklearn_reshape_apply(self._scaler.inverse_transform, True, epochs_data)
 
 
 class Vectorizer(TransformerMixin):
@@ -283,8 +293,7 @@ class Vectorizer(TransformerMixin):
         """
         X = np.asarray(X)
         if X.shape[1:] != self.features_shape_:
-            raise ValueError("Shape of X used in fit and transform must be "
-                             "same")
+            raise ValueError("Shape of X used in fit and transform must be " "same")
         return X.reshape(len(X), -1)
 
     def fit_transform(self, X, y=None):
@@ -323,8 +332,9 @@ class Vectorizer(TransformerMixin):
         """
         X = np.asarray(X)
         if X.ndim not in (2, 3):
-            raise ValueError("X should be of 2 or 3 dimensions but has shape "
-                             "%s" % (X.shape,))
+            raise ValueError(
+                "X should be of 2 or 3 dimensions but has shape " "%s" % (X.shape,)
+            )
         return X.reshape(X.shape[:-1] + self.features_shape_)
 
 
@@ -362,9 +372,19 @@ class PSDEstimator(TransformerMixin):
     """
 
     @verbose
-    def __init__(self, sfreq=2 * np.pi, fmin=0, fmax=np.inf, bandwidth=None,
-                 adaptive=False, low_bias=True, n_jobs=None,
-                 normalization='length', *, verbose=None):  # noqa: D102
+    def __init__(
+        self,
+        sfreq=2 * np.pi,
+        fmin=0,
+        fmax=np.inf,
+        bandwidth=None,
+        adaptive=False,
+        low_bias=True,
+        n_jobs=None,
+        normalization="length",
+        *,
+        verbose=None,
+    ):  # noqa: D102
         self.sfreq = sfreq
         self.fmin = fmin
         self.fmax = fmax
@@ -390,8 +410,9 @@ class PSDEstimator(TransformerMixin):
             The modified instance.
         """
         if not isinstance(epochs_data, np.ndarray):
-            raise ValueError("epochs_data should be of type ndarray (got %s)."
-                             % type(epochs_data))
+            raise ValueError(
+                "epochs_data should be of type ndarray (got %s)." % type(epochs_data)
+            )
 
         return self
 
@@ -409,13 +430,20 @@ class PSDEstimator(TransformerMixin):
             The computed PSD.
         """
         if not isinstance(epochs_data, np.ndarray):
-            raise ValueError("epochs_data should be of type ndarray (got %s)."
-                             % type(epochs_data))
+            raise ValueError(
+                "epochs_data should be of type ndarray (got %s)." % type(epochs_data)
+            )
         psd, _ = psd_array_multitaper(
-            epochs_data, sfreq=self.sfreq, fmin=self.fmin, fmax=self.fmax,
-            bandwidth=self.bandwidth, adaptive=self.adaptive,
-            low_bias=self.low_bias, normalization=self.normalization,
-            n_jobs=self.n_jobs)
+            epochs_data,
+            sfreq=self.sfreq,
+            fmin=self.fmin,
+            fmax=self.fmax,
+            bandwidth=self.bandwidth,
+            adaptive=self.adaptive,
+            low_bias=self.low_bias,
+            normalization=self.normalization,
+            n_jobs=self.n_jobs,
+        )
         return psd
 
 
@@ -450,8 +478,7 @@ class FilterEstimator(TransformerMixin):
         Number of jobs to run in parallel.
         Can be 'cuda' if ``cupy`` is installed properly and method='fir'.
     method : str
-        'fir' will use overlap-add FIR filtering, 'iir' will use IIR
-        forward-backward filtering (via filtfilt).
+        'fir' will use overlap-add FIR filtering, 'iir' will use IIR filtering.
     iir_params : dict | None
         Dictionary of parameters to use for IIR filtering.
         See mne.filter.construct_iir_filter for details. If iir_params
@@ -471,10 +498,22 @@ class FilterEstimator(TransformerMixin):
     caution.
     """
 
-    def __init__(self, info, l_freq, h_freq, picks=None, filter_length='auto',
-                 l_trans_bandwidth='auto', h_trans_bandwidth='auto',
-                 n_jobs=None, method='fir', iir_params=None,
-                 fir_design='firwin', *, verbose=None):  # noqa: D102
+    def __init__(
+        self,
+        info,
+        l_freq,
+        h_freq,
+        picks=None,
+        filter_length="auto",
+        l_trans_bandwidth="auto",
+        h_trans_bandwidth="auto",
+        n_jobs=None,
+        method="fir",
+        iir_params=None,
+        fir_design="firwin",
+        *,
+        verbose=None,
+    ):  # noqa: D102
         self.info = info
         self.l_freq = l_freq
         self.h_freq = h_freq
@@ -503,37 +542,39 @@ class FilterEstimator(TransformerMixin):
             The modified instance.
         """
         if not isinstance(epochs_data, np.ndarray):
-            raise ValueError("epochs_data should be of type ndarray (got %s)."
-                             % type(epochs_data))
+            raise ValueError(
+                "epochs_data should be of type ndarray (got %s)." % type(epochs_data)
+            )
 
         if self.picks is None:
-            self.picks = pick_types(self.info, meg=True, eeg=True,
-                                    ref_meg=False, exclude=[])
+            self.picks = pick_types(
+                self.info, meg=True, eeg=True, ref_meg=False, exclude=[]
+            )
 
         if self.l_freq == 0:
             self.l_freq = None
-        if self.h_freq is not None and self.h_freq > (self.info['sfreq'] / 2.):
+        if self.h_freq is not None and self.h_freq > (self.info["sfreq"] / 2.0):
             self.h_freq = None
         if self.l_freq is not None and not isinstance(self.l_freq, float):
             self.l_freq = float(self.l_freq)
         if self.h_freq is not None and not isinstance(self.h_freq, float):
             self.h_freq = float(self.h_freq)
 
-        if self.info['lowpass'] is None or (self.h_freq is not None and
-                                            (self.l_freq is None or
-                                             self.l_freq < self.h_freq) and
-                                            self.h_freq <
-                                            self.info['lowpass']):
+        if self.info["lowpass"] is None or (
+            self.h_freq is not None
+            and (self.l_freq is None or self.l_freq < self.h_freq)
+            and self.h_freq < self.info["lowpass"]
+        ):
             with self.info._unlock():
-                self.info['lowpass'] = self.h_freq
+                self.info["lowpass"] = self.h_freq
 
-        if self.info['highpass'] is None or (self.l_freq is not None and
-                                             (self.h_freq is None or
-                                              self.l_freq < self.h_freq) and
-                                             self.l_freq >
-                                             self.info['highpass']):
+        if self.info["highpass"] is None or (
+            self.l_freq is not None
+            and (self.h_freq is None or self.l_freq < self.h_freq)
+            and self.l_freq > self.info["highpass"]
+        ):
             with self.info._unlock():
-                self.info['highpass'] = self.l_freq
+                self.info["highpass"] = self.l_freq
 
         return self
 
@@ -551,15 +592,26 @@ class FilterEstimator(TransformerMixin):
             The data after filtering.
         """
         if not isinstance(epochs_data, np.ndarray):
-            raise ValueError("epochs_data should be of type ndarray (got %s)."
-                             % type(epochs_data))
+            raise ValueError(
+                "epochs_data should be of type ndarray (got %s)." % type(epochs_data)
+            )
         epochs_data = np.atleast_3d(epochs_data)
         return filter_data(
-            epochs_data, self.info['sfreq'], self.l_freq, self.h_freq,
-            self.picks, self.filter_length, self.l_trans_bandwidth,
-            self.h_trans_bandwidth, method=self.method,
-            iir_params=self.iir_params, n_jobs=self.n_jobs, copy=False,
-            fir_design=self.fir_design, verbose=False)
+            epochs_data,
+            self.info["sfreq"],
+            self.l_freq,
+            self.h_freq,
+            self.picks,
+            self.filter_length,
+            self.l_trans_bandwidth,
+            self.h_trans_bandwidth,
+            method=self.method,
+            iir_params=self.iir_params,
+            n_jobs=self.n_jobs,
+            copy=False,
+            fir_design=self.fir_design,
+            verbose=False,
+        )
 
 
 class UnsupervisedSpatialFilter(TransformerMixin, BaseEstimator):
@@ -576,14 +628,17 @@ class UnsupervisedSpatialFilter(TransformerMixin, BaseEstimator):
 
     def __init__(self, estimator, average=False):  # noqa: D102
         # XXX: Use _check_estimator #3381
-        for attr in ('fit', 'transform', 'fit_transform'):
+        for attr in ("fit", "transform", "fit_transform"):
             if not hasattr(estimator, attr):
-                raise ValueError('estimator must be a scikit-learn '
-                                 'transformer, missing %s method' % attr)
+                raise ValueError(
+                    "estimator must be a scikit-learn "
+                    "transformer, missing %s method" % attr
+                )
 
         if not isinstance(average, bool):
-            raise ValueError("average parameter must be of bool type, got "
-                             "%s instead" % type(bool))
+            raise ValueError(
+                "average parameter must be of bool type, got " "%s instead" % type(bool)
+            )
 
         self.estimator = estimator
         self.average = average
@@ -608,8 +663,7 @@ class UnsupervisedSpatialFilter(TransformerMixin, BaseEstimator):
         else:
             n_epochs, n_channels, n_times = X.shape
             # trial as time samples
-            X = np.transpose(X, (1, 0, 2)).reshape((n_channels, n_epochs *
-                                                    n_times)).T
+            X = np.transpose(X, (1, 0, 2)).reshape((n_channels, n_epochs * n_times)).T
         self.estimator.fit(X)
         return self
 
@@ -643,7 +697,7 @@ class UnsupervisedSpatialFilter(TransformerMixin, BaseEstimator):
         X : array, shape (n_epochs, n_channels, n_times)
             The transformed data.
         """
-        return self._apply_method(X, 'transform')
+        return self._apply_method(X, "transform")
 
     def inverse_transform(self, X):
         """Inverse transform the data to its original space.
@@ -658,7 +712,7 @@ class UnsupervisedSpatialFilter(TransformerMixin, BaseEstimator):
         X : array, shape (n_epochs, n_channels, n_times)
             The transformed data.
         """
-        return self._apply_method(X, 'inverse_transform')
+        return self._apply_method(X, "inverse_transform")
 
     def _apply_method(self, X, method):
         """Vectorize time samples as trials, apply method and reshape back.
@@ -770,11 +824,22 @@ class TemporalFilter(TransformerMixin):
     """
 
     @verbose
-    def __init__(self, l_freq=None, h_freq=None, sfreq=1.0,
-                 filter_length='auto', l_trans_bandwidth='auto',
-                 h_trans_bandwidth='auto', n_jobs=None, method='fir',
-                 iir_params=None, fir_window='hamming', fir_design='firwin',
-                 *, verbose=None):  # noqa: D102
+    def __init__(
+        self,
+        l_freq=None,
+        h_freq=None,
+        sfreq=1.0,
+        filter_length="auto",
+        l_trans_bandwidth="auto",
+        h_trans_bandwidth="auto",
+        n_jobs=None,
+        method="fir",
+        iir_params=None,
+        fir_window="hamming",
+        fir_design="firwin",
+        *,
+        verbose=None,
+    ):  # noqa: D102
         self.l_freq = l_freq
         self.h_freq = h_freq
         self.sfreq = sfreq
@@ -787,9 +852,10 @@ class TemporalFilter(TransformerMixin):
         self.fir_window = fir_window
         self.fir_design = fir_design
 
-        if not isinstance(self.n_jobs, int) and self.n_jobs == 'cuda':
-            raise ValueError('n_jobs must be int or "cuda", got %s instead.'
-                             % type(self.n_jobs))
+        if not isinstance(self.n_jobs, int) and self.n_jobs == "cuda":
+            raise ValueError(
+                'n_jobs must be int or "cuda", got %s instead.' % type(self.n_jobs)
+            )
 
     def fit(self, X, y=None):
         """Do nothing (for scikit-learn compatibility purposes).
@@ -826,16 +892,26 @@ class TemporalFilter(TransformerMixin):
         X = np.atleast_2d(X)
 
         if X.ndim > 3:
-            raise ValueError("Array must be of at max 3 dimensions instead "
-                             "got %s dimensional matrix" % (X.ndim))
+            raise ValueError(
+                "Array must be of at max 3 dimensions instead "
+                "got %s dimensional matrix" % (X.ndim)
+            )
 
         shape = X.shape
         X = X.reshape(-1, shape[-1])
-        X = filter_data(X, self.sfreq, self.l_freq, self.h_freq,
-                        filter_length=self.filter_length,
-                        l_trans_bandwidth=self.l_trans_bandwidth,
-                        h_trans_bandwidth=self.h_trans_bandwidth,
-                        n_jobs=self.n_jobs, method=self.method,
-                        iir_params=self.iir_params, copy=False,
-                        fir_window=self.fir_window, fir_design=self.fir_design)
+        X = filter_data(
+            X,
+            self.sfreq,
+            self.l_freq,
+            self.h_freq,
+            filter_length=self.filter_length,
+            l_trans_bandwidth=self.l_trans_bandwidth,
+            h_trans_bandwidth=self.h_trans_bandwidth,
+            n_jobs=self.n_jobs,
+            method=self.method,
+            iir_params=self.iir_params,
+            copy=False,
+            fir_window=self.fir_window,
+            fir_design=self.fir_design,
+        )
         return X.reshape(shape)
