@@ -1,12 +1,14 @@
-# -*- coding: utf-8 -*-
 # Authors: MNE Developers
 #
 # License: BSD-3-Clause
+# Copyright the MNE-Python contributors.
 
 from contextlib import contextmanager
+
 import numpy as np
 
 from ..utils import _check_edflib_installed, warn
+
 _check_edflib_installed()
 from EDFlib.edfwriter import EDFwriter  # noqa: E402
 
@@ -15,7 +17,7 @@ def _try_to_set_value(header, key, value, channel_index=None):
     """Set key/value pairs in EDF header."""
     # all EDFLib set functions are set<X>
     # for example "setPatientName()"
-    func_name = f'set{key}'
+    func_name = f"set{key}"
     func = getattr(header, func_name)
 
     # some setter functions are indexed by channels
@@ -26,9 +28,9 @@ def _try_to_set_value(header, key, value, channel_index=None):
 
     # a nonzero return value indicates an error
     if return_val != 0:
-        raise RuntimeError(f"Setting {key} with {value} "
-                           f"returned an error value "
-                           f"{return_val}.")
+        raise RuntimeError(
+            f"Setting {key} with {value} " f"returned an error value " f"{return_val}."
+        )
 
 
 @contextmanager
@@ -50,11 +52,12 @@ def _export_raw(fname, raw, physical_range, add_ch_type):
     technician information, allow writing those here.
     """
     # scale to save data in EDF
-    phys_dims = 'uV'
+    phys_dims = "uV"
 
     # get EEG-related data in uV
-    units = dict(eeg='uV', ecog='uV', seeg='uV', eog='uV', ecg='uV', emg='uV',
-                 bio='uV', dbs='uV')
+    units = dict(
+        eeg="uV", ecog="uV", seeg="uV", eog="uV", ecg="uV", emg="uV", bio="uV", dbs="uV"
+    )
 
     digital_min = -32767
     digital_max = 32767
@@ -66,8 +69,8 @@ def _export_raw(fname, raw, physical_range, add_ch_type):
     # remove extra STI channels
     orig_ch_types = raw.get_channel_types()
     drop_chs = []
-    if 'stim' in orig_ch_types:
-        stim_index = np.argwhere(np.array(orig_ch_types) == 'stim')
+    if "stim" in orig_ch_types:
+        stim_index = np.argwhere(np.array(orig_ch_types) == "stim")
         stim_index = np.atleast_1d(stim_index.squeeze()).tolist()
         drop_chs.extend([raw.ch_names[idx] for idx in stim_index])
 
@@ -78,17 +81,19 @@ def _export_raw(fname, raw, physical_range, add_ch_type):
     # Note: we can write these other channels, such as 'misc'
     # but these are simply a "catch all" for unknown or undesired
     # channels.
-    voltage_types = list(units) + ['stim', 'misc']
+    voltage_types = list(units) + ["stim", "misc"]
     non_voltage_ch = [ch not in voltage_types for ch in orig_ch_types]
     if any(non_voltage_ch):
-        warn(f"Non-voltage channels detected: {non_voltage_ch}. MNE-Python's "
-             'EDF exporter only supports voltage-based channels, because the '
-             'EDF format cannot accommodate much of the accompanying data '
-             'necessary for channel types like MEG and fNIRS (channel '
-             'orientations, coordinate frame transforms, etc). You can '
-             'override this restriction by setting those channel types to '
-             '"misc" but no guarantees are made of the fidelity of that '
-             'approach.')
+        warn(
+            f"Non-voltage channels detected: {non_voltage_ch}. MNE-Python's "
+            "EDF exporter only supports voltage-based channels, because the "
+            "EDF format cannot accommodate much of the accompanying data "
+            "necessary for channel types like MEG and fNIRS (channel "
+            "orientations, coordinate frame transforms, etc). You can "
+            "override this restriction by setting those channel types to "
+            '"misc" but no guarantees are made of the fidelity of that '
+            "approach."
+        )
 
     ch_names = [ch for ch in raw.ch_names if ch not in drop_chs]
     ch_types = np.array(raw.get_channel_types(picks=ch_names))
@@ -98,28 +103,29 @@ def _export_raw(fname, raw, physical_range, add_ch_type):
     # Sampling frequency in EDF only supports integers, so to allow for
     # float sampling rates from Raw, we adjust the output sampling rate
     # for all channels and the data record duration.
-    sfreq = raw.info['sfreq']
+    sfreq = raw.info["sfreq"]
     if float(sfreq).is_integer():
         out_sfreq = int(sfreq)
         data_record_duration = None
     else:
         out_sfreq = np.floor(sfreq).astype(int)
-        data_record_duration = int(np.around(
-            out_sfreq / sfreq, decimals=6) * 1e6)
+        data_record_duration = int(np.around(out_sfreq / sfreq, decimals=6) * 1e6)
 
-        warn(f'Data has a non-integer sampling rate of {sfreq}; writing to '
-             'EDF format may cause a small change to sample times.')
+        warn(
+            f"Data has a non-integer sampling rate of {sfreq}; writing to "
+            "EDF format may cause a small change to sample times."
+        )
 
     # get any filter information applied to the data
-    lowpass = raw.info['lowpass']
-    highpass = raw.info['highpass']
-    linefreq = raw.info['line_freq']
+    lowpass = raw.info["lowpass"]
+    highpass = raw.info["highpass"]
+    linefreq = raw.info["line_freq"]
     filter_str_info = f"HP:{highpass}Hz LP:{lowpass}Hz N:{linefreq}Hz"
 
     # get the entire dataset in uV
     data = raw.get_data(units=units, picks=ch_names)
 
-    if physical_range == 'auto':
+    if physical_range == "auto":
         # get max and min for each channel type data
         ch_types_phys_max = dict()
         ch_types_phys_min = dict()
@@ -142,65 +148,82 @@ def _export_raw(fname, raw, physical_range, add_ch_type):
 
         # check that physical min and max is not exceeded
         if data.max() > pmax:
-            raise RuntimeError(f'The maximum μV of the data {data.max()} is '
-                               f'more than the physical max passed in {pmax}.')
+            warn(
+                f"The maximum μV of the data {data.max()} is "
+                f"more than the physical max passed in {pmax}.",
+            )
         if data.min() < pmin:
-            raise RuntimeError(f'The minimum μV of the data {data.min()} is '
-                               f'less than the physical min passed in {pmin}.')
+            warn(
+                f"The minimum μV of the data {data.min()} is "
+                f"less than the physical min passed in {pmin}.",
+            )
 
     # create instance of EDF Writer
     with _auto_close(EDFwriter(fname, file_type, n_channels)) as hdl:
         # set channel data
         for idx, ch in enumerate(ch_names):
             ch_type = ch_types[idx]
-            signal_label = f'{ch_type.upper()} {ch}' if add_ch_type else ch
+            signal_label = f"{ch_type.upper()} {ch}" if add_ch_type else ch
             if len(signal_label) > 16:
-                raise RuntimeError(f'Signal label for {ch} ({ch_type}) is '
-                                   f'longer than 16 characters, which is not '
-                                   f'supported in EDF. Please shorten the '
-                                   f'channel name before exporting to EDF.')
+                raise RuntimeError(
+                    f"Signal label for {ch} ({ch_type}) is "
+                    f"longer than 16 characters, which is not "
+                    f"supported in EDF. Please shorten the "
+                    f"channel name before exporting to EDF."
+                )
 
-            if physical_range == 'auto':
+            if physical_range == "auto":
                 # take the channel type minimum and maximum
                 pmin = ch_types_phys_min[ch_type]
                 pmax = ch_types_phys_max[ch_type]
-            for key, val in [('PhysicalMaximum', pmax),
-                             ('PhysicalMinimum', pmin),
-                             ('DigitalMaximum', digital_max),
-                             ('DigitalMinimum', digital_min),
-                             ('PhysicalDimension', phys_dims),
-                             ('SampleFrequency', out_sfreq),
-                             ('SignalLabel', signal_label),
-                             ('PreFilter', filter_str_info)]:
+            for key, val in [
+                ("PhysicalMaximum", pmax),
+                ("PhysicalMinimum", pmin),
+                ("DigitalMaximum", digital_max),
+                ("DigitalMinimum", digital_min),
+                ("PhysicalDimension", phys_dims),
+                ("SampleFrequency", out_sfreq),
+                ("SignalLabel", signal_label),
+                ("PreFilter", filter_str_info),
+            ]:
                 _try_to_set_value(hdl, key, val, channel_index=idx)
 
         # set patient info
-        subj_info = raw.info.get('subject_info')
+        subj_info = raw.info.get("subject_info")
         if subj_info is not None:
-            birthday = subj_info.get('birthday')
-
             # get the full name of subject if available
-            first_name = subj_info.get('first_name')
-            last_name = subj_info.get('last_name')
-            first_name = first_name or ''
-            last_name = last_name or ''
-            joiner = ''
-            if len(first_name) and len(last_name):
-                joiner = ' '
-            name = joiner.join([first_name, last_name])
+            first_name = subj_info.get("first_name", "")
+            middle_name = subj_info.get("middle_name", "")
+            last_name = subj_info.get("last_name", "")
+            name = " ".join(filter(None, [first_name, middle_name, last_name]))
 
-            hand = subj_info.get('hand')
-            sex = subj_info.get('sex')
+            birthday = subj_info.get("birthday")
+            hand = subj_info.get("hand")
+            weight = subj_info.get("weight")
+            height = subj_info.get("height")
+            sex = subj_info.get("sex")
+
+            additional_patient_info = []
+            for key, value in [("height", height), ("weight", weight), ("hand", hand)]:
+                if value:
+                    additional_patient_info.append(f"{key}={value}")
+            if len(additional_patient_info) == 0:
+                additional_patient_info = None
+            else:
+                additional_patient_info = " ".join(additional_patient_info)
 
             if birthday is not None:
-                if hdl.setPatientBirthDate(birthday[0], birthday[1],
-                                           birthday[2]) != 0:
+                if hdl.setPatientBirthDate(birthday[0], birthday[1], birthday[2]) != 0:
                     raise RuntimeError(
                         f"Setting patient birth date to {birthday} "
-                        f"returned an error")
-            for key, val in [('PatientName', name),
-                             ('PatientGender', sex),
-                             ('AdditionalPatientInfo', f'hand={hand}')]:
+                        f"returned an error"
+                    )
+            for key, val in [
+                ("PatientCode", subj_info.get("his_id", "")),
+                ("PatientName", name),
+                ("PatientGender", sex),
+                ("AdditionalPatientInfo", additional_patient_info),
+            ]:
                 # EDFwriter compares integer encodings of sex and will
                 # raise a TypeError if value is None as returned by
                 # subj_info.get(key) if key is missing.
@@ -208,25 +231,33 @@ def _export_raw(fname, raw, physical_range, add_ch_type):
                     _try_to_set_value(hdl, key, val)
 
         # set measurement date
-        meas_date = raw.info['meas_date']
+        meas_date = raw.info["meas_date"]
         if meas_date:
             subsecond = int(meas_date.microsecond / 100)
-            if hdl.setStartDateTime(year=meas_date.year, month=meas_date.month,
-                                    day=meas_date.day, hour=meas_date.hour,
-                                    minute=meas_date.minute,
-                                    second=meas_date.second,
-                                    subsecond=subsecond) != 0:
-                raise RuntimeError(f"Setting start date time {meas_date} "
-                                   f"returned an error")
+            if (
+                hdl.setStartDateTime(
+                    year=meas_date.year,
+                    month=meas_date.month,
+                    day=meas_date.day,
+                    hour=meas_date.hour,
+                    minute=meas_date.minute,
+                    second=meas_date.second,
+                    subsecond=subsecond,
+                )
+                != 0
+            ):
+                raise RuntimeError(
+                    f"Setting start date time {meas_date} " f"returned an error"
+                )
 
-        device_info = raw.info.get('device_info')
+        device_info = raw.info.get("device_info")
         if device_info is not None:
-            device_type = device_info.get('type')
-            _try_to_set_value(hdl, 'Equipment', device_type)
+            device_type = device_info.get("type")
+            _try_to_set_value(hdl, "Equipment", device_type)
 
         # set data record duration
         if data_record_duration is not None:
-            _try_to_set_value(hdl, 'DataRecordDuration', data_record_duration)
+            _try_to_set_value(hdl, "DataRecordDuration", data_record_duration)
 
         # compute number of data records to loop over
         n_blocks = np.ceil(n_times / out_sfreq).astype(int)
@@ -235,9 +266,7 @@ def _export_raw(fname, raw, physical_range, add_ch_type):
         annots = raw.annotations
         if annots is not None:
             n_annotations = len(raw.annotations)
-            n_annot_chans = int(n_annotations / n_blocks)
-            if np.mod(n_annotations, n_blocks):
-                n_annot_chans += 1
+            n_annot_chans = int(n_annotations / n_blocks) + 1
             if n_annot_chans > 1:
                 hdl.setNumberOfAnnotationSignals(n_annot_chans)
 
@@ -257,29 +286,49 @@ def _export_raw(fname, raw, physical_range, add_ch_type):
                 ch_data = data[jdx, start_samp:end_samp]
 
                 # assign channel data to the buffer and write to EDF
-                buf[:len(ch_data)] = ch_data
+                buf[: len(ch_data)] = ch_data
                 err = hdl.writeSamples(buf)
                 if err != 0:
                     raise RuntimeError(
                         f"writeSamples() for channel{ch_names[jdx]} "
-                        f"returned error: {err}")
+                        f"returned error: {err}"
+                    )
 
             # there was an incomplete datarecord
             if len(ch_data) != len(buf):
-                warn(f'EDF format requires equal-length data blocks, '
-                     f'so {(len(buf) - len(ch_data)) / sfreq} seconds of '
-                     'zeros were appended to all channels when writing the '
-                     'final block.')
+                warn(
+                    f"EDF format requires equal-length data blocks, "
+                    f"so {(len(buf) - len(ch_data)) / sfreq} seconds of "
+                    "zeros were appended to all channels when writing the "
+                    "final block."
+                )
 
         # write annotations
         if annots is not None:
-            for desc, onset, duration in zip(raw.annotations.description,
-                                             raw.annotations.onset,
-                                             raw.annotations.duration):
+            for desc, onset, duration, ch_names in zip(
+                raw.annotations.description,
+                raw.annotations.onset,
+                raw.annotations.duration,
+                raw.annotations.ch_names,
+            ):
                 # annotations are written in terms of 100 microseconds
                 onset = onset * 10000
                 duration = duration * 10000
-                if hdl.writeAnnotation(onset, duration, desc) != 0:
-                    raise RuntimeError(f'writeAnnotation() returned an error '
-                                       f'trying to write {desc} at {onset} '
-                                       f'for {duration} seconds.')
+                if ch_names:
+                    for ch_name in ch_names:
+                        if (
+                            hdl.writeAnnotation(onset, duration, desc + f"@@{ch_name}")
+                            != 0
+                        ):
+                            raise RuntimeError(
+                                f"writeAnnotation() returned an error "
+                                f"trying to write {desc}@@{ch_name} at {onset} "
+                                f"for {duration} seconds."
+                            )
+                else:
+                    if hdl.writeAnnotation(onset, duration, desc) != 0:
+                        raise RuntimeError(
+                            f"writeAnnotation() returned an error "
+                            f"trying to write {desc} at {onset} "
+                            f"for {duration} seconds."
+                        )
