@@ -4,6 +4,7 @@
 #          Eric Larson <larson.eric.d@gmail.com>
 #
 # License: BSD-3-Clause
+# Copyright the MNE-Python contributors.
 
 from ...utils import BunchConst
 
@@ -36,4 +37,4 @@ CTF.FUNNY_POS = 1844
 # read_write_data.c
 CTF.HEADER_SIZE = 8
 CTF.BLOCK_SIZE = 2000
-CTF.SYSTEM_CLOCK_CH = 'SCLK01-177'
+CTF.SYSTEM_CLOCK_CH = "SCLK01-177"
