@@ -3,6 +3,6 @@
 #          Dirk Gütlin <dirk.guetlin@stud.sbg.ac.at>
 #
 # License: BSD-3-Clause
+# Copyright the MNE-Python contributors.
 
-from .fieldtrip import (read_evoked_fieldtrip, read_epochs_fieldtrip,
-                        read_raw_fieldtrip)
+from .fieldtrip import read_evoked_fieldtrip, read_epochs_fieldtrip, read_raw_fieldtrip
