@@ -1,7 +1,7 @@
-# -*- coding: utf-8 -*-
 # Authors: Olaf Hauk <olaf.hauk@mrc-cbu.cam.ac.uk>
 #
 # License: BSD-3-Clause
+# Copyright the MNE-Python contributors.
 """Compute resolution metrics from resolution matrix.
 
 Resolution metrics: localisation error, spatial extent, relative amplitude.
@@ -9,13 +9,14 @@ Metrics can be computed for point-spread and cross-talk functions (PSFs/CTFs).
 """
 import numpy as np
 
-from .. import SourceEstimate
-from ..utils import logger, verbose, _check_option
+from ..source_estimate import SourceEstimate
+from ..utils import _check_option, logger, verbose
 
 
 @verbose
-def resolution_metrics(resmat, src, function='psf', metric='peak_err',
-                       threshold=0.5, verbose=None):
+def resolution_metrics(
+    resmat, src, function="psf", metric="peak_err", threshold=0.5, verbose=None
+):
     """Compute spatial resolution metrics for linear solvers.
 
     Parameters
@@ -75,35 +76,35 @@ def resolution_metrics(resmat, src, function='psf', metric='peak_err',
     .. footbibliography::
     """
     # Check if input options are valid
-    metrics = ('peak_err', 'cog_err', 'sd_ext', 'maxrad_ext', 'peak_amp',
-               'sum_amp')
+    metrics = ("peak_err", "cog_err", "sd_ext", "maxrad_ext", "peak_amp", "sum_amp")
     if metric not in metrics:
         raise ValueError('"%s" is not a recognized metric.' % metric)
 
-    if function not in ['psf', 'ctf']:
-        raise ValueError('Not a recognised resolution function: %s.'
-                         % function)
+    if function not in ["psf", "ctf"]:
+        raise ValueError("Not a recognised resolution function: %s." % function)
 
-    if metric in ('peak_err', 'cog_err'):
-        resolution_metric = _localisation_error(resmat, src, function=function,
-                                                metric=metric)
+    if metric in ("peak_err", "cog_err"):
+        resolution_metric = _localisation_error(
+            resmat, src, function=function, metric=metric
+        )
 
-    elif metric in ('sd_ext', 'maxrad_ext'):
-        resolution_metric = _spatial_extent(resmat, src, function=function,
-                                            metric=metric, threshold=threshold)
+    elif metric in ("sd_ext", "maxrad_ext"):
+        resolution_metric = _spatial_extent(
+            resmat, src, function=function, metric=metric, threshold=threshold
+        )
 
-    elif metric in ('peak_amp', 'sum_amp'):
-        resolution_metric = _relative_amplitude(resmat, src, function=function,
-                                                metric=metric)
+    elif metric in ("peak_amp", "sum_amp"):
+        resolution_metric = _relative_amplitude(
+            resmat, src, function=function, metric=metric
+        )
 
     # get vertices from source space
-    vertno_lh = src[0]['vertno']
-    vertno_rh = src[1]['vertno']
+    vertno_lh = src[0]["vertno"]
+    vertno_rh = src[1]["vertno"]
     vertno = [vertno_lh, vertno_rh]
 
     # Convert array to source estimate
-    resolution_metric = SourceEstimate(resolution_metric, vertno, tmin=0.,
-                                       tstep=1.)
+    resolution_metric = SourceEstimate(resolution_metric, vertno, tmin=0.0, tstep=1.0)
 
     return resolution_metric
 
@@ -141,27 +142,27 @@ def _localisation_error(resmat, src, function, metric):
     # combine rows (Euclidean length) if necessary
     resmat = _rectify_resolution_matrix(resmat)
     locations = _get_src_locations(src)  # locs used in forw. and inv. operator
-    locations = 100. * locations  # convert to cm (more common)
+    locations = 100.0 * locations  # convert to cm (more common)
     # we want to use absolute values, but doing abs() mases a copy and this
     # can be quite expensive in memory. So let's just use abs() in place below.
 
     # The code below will operate on columns, so transpose if you want CTFs
-    if function == 'ctf':
+    if function == "ctf":
         resmat = resmat.T
 
     # Euclidean distance between true location and maximum
-    if metric == 'peak_err':
+    if metric == "peak_err":
         resmax = [abs(col).argmax() for col in resmat.T]  # max inds along cols
-        maxloc = locations[resmax, :]   # locations of maxima
-        diffloc = locations - maxloc    # diff btw true locs and maxima locs
+        maxloc = locations[resmax, :]  # locations of maxima
+        diffloc = locations - maxloc  # diff btw true locs and maxima locs
         locerr = np.linalg.norm(diffloc, axis=1)  # Euclidean distance
 
     # centre of gravity
-    elif metric == 'cog_err':
+    elif metric == "cog_err":
         locerr = np.empty(locations.shape[0])  # initialise result array
         for ii, rr in enumerate(locations):
             resvec = abs(resmat[:, ii].T)  # corresponding column of resmat
-            cog = resvec.dot(locations) / np.sum(resvec)   # centre of gravity
+            cog = resvec.dot(locations) / np.sum(resvec)  # centre of gravity
             locerr[ii] = np.sqrt(np.sum((rr - cog) ** 2))  # Euclidean distance
 
     return locerr
@@ -198,27 +199,25 @@ def _spatial_extent(resmat, src, function, metric, threshold=0.5):
         Spatial width metric per location.
     """
     locations = _get_src_locations(src)  # locs used in forw. and inv. operator
-    locations = 100. * locations  # convert to cm (more common)
+    locations = 100.0 * locations  # convert to cm (more common)
 
     # The code below will operate on columns, so transpose if you want CTFs
-    if function == 'ctf':
+    if function == "ctf":
         resmat = resmat.T
 
-    width = np.empty(resmat.shape[1])   # initialise output array
+    width = np.empty(resmat.shape[1])  # initialise output array
 
     # spatial deviation as in Molins et al.
-    if metric == 'sd_ext':
+    if metric == "sd_ext":
         for ii in range(locations.shape[0]):
-
             diffloc = locations - locations[ii, :]  # locs w/r/t true source
             locerr = np.sum(diffloc**2, 1)  # squared Eucl dists to true source
-            resvec = abs(resmat[:, ii]) ** 2       # pick current row
+            resvec = abs(resmat[:, ii]) ** 2  # pick current row
             # spatial deviation (Molins et al, NI 2008, eq. 12)
-            width[ii] = np.sqrt(np.sum(np.multiply(locerr, resvec)) /
-                                np.sum(resvec))
+            width[ii] = np.sqrt(np.sum(np.multiply(locerr, resvec)) / np.sum(resvec))
 
     # maximum radius to 50% of max amplitude
-    elif metric == 'maxrad_ext':
+    elif metric == "maxrad_ext":
         for ii, resvec in enumerate(resmat.T):  # iterate over columns
             resvec = abs(resvec)  # operate on absolute values
             amps = resvec.max()
@@ -261,21 +260,21 @@ def _relative_amplitude(resmat, src, function, metric):
         Relative amplitude metric per location.
     """
     # The code below will operate on columns, so transpose if you want CTFs
-    if function == 'ctf':
+    if function == "ctf":
         resmat = resmat.T
 
     # Ratio between amplitude at peak and global peak maximum
-    if metric == 'peak_amp':
+    if metric == "peak_amp":
         # maximum amplitudes per column
         maxamps = np.array([abs(col).max() for col in resmat.T])
-        maxmaxamps = maxamps.max()    # global absolute maximum
+        maxmaxamps = maxamps.max()  # global absolute maximum
         relamp = maxamps / maxmaxamps
 
     # ratio between sums of absolute amplitudes
-    elif metric == 'sum_amp':
+    elif metric == "sum_amp":
         # sum of amplitudes per column
         sumamps = np.array([abs(col).sum() for col in resmat.T])
-        sumampsmax = sumamps.max()        # maximum of summed amplitudes
+        sumampsmax = sumamps.max()  # maximum of summed amplitudes
         relamp = sumamps / sumampsmax
 
     return relamp
@@ -285,13 +284,13 @@ def _get_src_locations(src):
     """Get source positions from src object."""
     # vertices used in forward and inverse operator
     # for now let's just support surface source spaces
-    _check_option('source space kind', src.kind, ('surface',))
-    vertno_lh = src[0]['vertno']
-    vertno_rh = src[1]['vertno']
+    _check_option("source space kind", src.kind, ("surface",))
+    vertno_lh = src[0]["vertno"]
+    vertno_rh = src[1]["vertno"]
 
     # locations corresponding to vertices for both hemispheres
-    locations_lh = src[0]['rr'][vertno_lh, :]
-    locations_rh = src[1]['rr'][vertno_rh, :]
+    locations_lh = src[0]["rr"][vertno_lh, :]
+    locations_rh = src[1]["rr"][vertno_rh, :]
     locations = np.vstack([locations_lh, locations_rh])
 
     return locations
@@ -309,24 +308,32 @@ def _rectify_resolution_matrix(resmat):
     shape = resmat.shape
     if not shape[0] == shape[1]:
         if shape[0] < shape[1]:
-            raise ValueError('Number of target sources (%d) cannot be lower '
-                             'than number of input sources (%d)' % shape[0],
-                             shape[1])
+            raise ValueError(
+                "Number of target sources (%d) cannot be lower "
+                "than number of input sources (%d)" % shape[0],
+                shape[1],
+            )
 
         if np.mod(shape[0], shape[1]):  # if ratio not integer
-            raise ValueError('Number of target sources (%d) must be a '
-                             'multiple of the number of input sources (%d)'
-                             % shape[0], shape[1])
+            raise ValueError(
+                "Number of target sources (%d) must be a "
+                "multiple of the number of input sources (%d)" % shape[0],
+                shape[1],
+            )
 
         ns = shape[0] // shape[1]  # number of source components per vertex
 
         # Combine rows of resolution matrix
-        resmatl = [np.sqrt((resmat[ns * i:ns * (i + 1), :]**2).sum(axis=0))
-                   for i in np.arange(0, shape[1], dtype=int)]
+        resmatl = [
+            np.sqrt((resmat[ns * i : ns * (i + 1), :] ** 2).sum(axis=0))
+            for i in np.arange(0, shape[1], dtype=int)
+        ]
 
         resmat = np.array(resmatl)
 
-        logger.info('Rectified resolution matrix from (%d, %d) to (%d, %d).' %
-                    (shape[0], shape[1], resmat.shape[0], resmat.shape[1]))
+        logger.info(
+            "Rectified resolution matrix from (%d, %d) to (%d, %d)."
+            % (shape[0], shape[1], resmat.shape[0], resmat.shape[1])
+        )
 
     return resmat
