@@ -3,20 +3,30 @@
 #          Eric Larson <larson.eric.d@gmail.com>
 #
 # License: BSD-3-Clause
+# Copyright the MNE-Python contributors.
 
 import numpy as np
 
-from ._peak_finder import peak_finder
-from .. import pick_types, pick_channels
-from ..utils import logger, verbose, _pl, _validate_type
-from ..filter import filter_data
+from .._fiff.pick import pick_channels, pick_types
 from ..epochs import Epochs
+from ..filter import filter_data
+from ..utils import _pl, _validate_type, logger, verbose
+from ._peak_finder import peak_finder
 
 
 @verbose
-def find_eog_events(raw, event_id=998, l_freq=1, h_freq=10,
-                    filter_length='10s', ch_name=None, tstart=0,
-                    reject_by_annotation=False, thresh=None, verbose=None):
+def find_eog_events(
+    raw,
+    event_id=998,
+    l_freq=1,
+    h_freq=10,
+    filter_length="10s",
+    ch_name=None,
+    tstart=0,
+    reject_by_annotation=False,
+    thresh=None,
+    verbose=None,
+):
     """Locate EOG artifacts.
 
     .. note:: To control true-positive and true-negative detection rates, you
@@ -59,87 +69,141 @@ def find_eog_events(raw, event_id=998, l_freq=1, h_freq=10,
     """
     # Getting EOG Channel
     eog_inds = _get_eog_channel_index(ch_name, raw)
-    logger.info('EOG channel index for this subject is: %s' % eog_inds)
+    eog_names = np.array(raw.ch_names)[eog_inds]  # for logging
+    logger.info("EOG channel index for this subject is: %s" % eog_inds)
 
     # Reject bad segments.
-    reject_by_annotation = 'omit' if reject_by_annotation else None
-    eog, times = raw.get_data(picks=eog_inds,
-                              reject_by_annotation=reject_by_annotation,
-                              return_times=True)
-    times = times * raw.info['sfreq'] + raw.first_samp
+    reject_by_annotation = "omit" if reject_by_annotation else None
+    eog, times = raw.get_data(
+        picks=eog_inds, reject_by_annotation=reject_by_annotation, return_times=True
+    )
+    times = times * raw.info["sfreq"] + raw.first_samp
 
-    eog_events = _find_eog_events(eog, event_id=event_id, l_freq=l_freq,
-                                  h_freq=h_freq,
-                                  sampling_rate=raw.info['sfreq'],
-                                  first_samp=raw.first_samp,
-                                  filter_length=filter_length,
-                                  tstart=tstart, thresh=thresh,
-                                  verbose=verbose)
+    eog_events = _find_eog_events(
+        eog,
+        ch_names=eog_names,
+        event_id=event_id,
+        l_freq=l_freq,
+        h_freq=h_freq,
+        sampling_rate=raw.info["sfreq"],
+        first_samp=raw.first_samp,
+        filter_length=filter_length,
+        tstart=tstart,
+        thresh=thresh,
+        verbose=verbose,
+    )
     # Map times to corresponding samples.
-    eog_events[:, 0] = np.round(times[eog_events[:, 0] -
-                                      raw.first_samp]).astype(int)
+    eog_events[:, 0] = np.round(times[eog_events[:, 0] - raw.first_samp]).astype(int)
     return eog_events
 
 
 @verbose
-def _find_eog_events(eog, event_id, l_freq, h_freq, sampling_rate, first_samp,
-                     filter_length='10s', tstart=0., thresh=None,
-                     verbose=None):
+def _find_eog_events(
+    eog,
+    *,
+    ch_names,
+    event_id,
+    l_freq,
+    h_freq,
+    sampling_rate,
+    first_samp,
+    filter_length="10s",
+    tstart=0.0,
+    thresh=None,
+    verbose=None,
+):
     """Find EOG events."""
-    logger.info('Filtering the data to remove DC offset to help '
-                'distinguish blinks from saccades')
+    logger.info(
+        "Filtering the data to remove DC offset to help "
+        "distinguish blinks from saccades"
+    )
 
     # filtering to remove dc offset so that we know which is blink and saccades
     # hardcode verbose=False to suppress filter param messages (since this
     # filter is not under user control)
     fmax = np.minimum(45, sampling_rate / 2.0 - 0.75)  # protect Nyquist
-    filteog = np.array([filter_data(
-        x, sampling_rate, 2, fmax, None, filter_length, 0.5, 0.5,
-        phase='zero-double', fir_window='hann', fir_design='firwin2',
-        verbose=False) for x in eog])
-    temp = np.sqrt(np.sum(filteog ** 2, axis=1))
-
+    filteog = np.array(
+        [
+            filter_data(
+                x,
+                sampling_rate,
+                2,
+                fmax,
+                None,
+                filter_length,
+                0.5,
+                0.5,
+                phase="zero-double",
+                fir_window="hann",
+                fir_design="firwin2",
+                verbose=False,
+            )
+            for x in eog
+        ]
+    )
+    temp = np.sqrt(np.sum(filteog**2, axis=1))
     indexmax = np.argmax(temp)
+    if ch_names is not None:  # it can be None if called from ica_find_eog_events
+        logger.info(f"Selecting channel {ch_names[indexmax]} for blink detection")
 
     # easier to detect peaks with filtering.
     filteog = filter_data(
-        eog[indexmax], sampling_rate, l_freq, h_freq, None,
-        filter_length, 0.5, 0.5, phase='zero-double', fir_window='hann',
-        fir_design='firwin2')
+        eog[indexmax],
+        sampling_rate,
+        l_freq,
+        h_freq,
+        None,
+        filter_length,
+        0.5,
+        0.5,
+        phase="zero-double",
+        fir_window="hann",
+        fir_design="firwin2",
+    )
 
     # detecting eog blinks and generating event file
 
-    logger.info('Now detecting blinks and generating corresponding events')
+    logger.info("Now detecting blinks and generating corresponding events")
 
     temp = filteog - np.mean(filteog)
     n_samples_start = int(sampling_rate * tstart)
     if np.abs(np.max(temp)) > np.abs(np.min(temp)):
-        eog_events, _ = peak_finder(filteog[n_samples_start:],
-                                    thresh, extrema=1)
+        eog_events, _ = peak_finder(filteog[n_samples_start:], thresh, extrema=1)
     else:
-        eog_events, _ = peak_finder(filteog[n_samples_start:],
-                                    thresh, extrema=-1)
+        eog_events, _ = peak_finder(filteog[n_samples_start:], thresh, extrema=-1)
 
     eog_events += n_samples_start
     n_events = len(eog_events)
-    logger.info(f'Number of EOG events detected: {n_events}')
-    eog_events = np.array([eog_events + first_samp,
-                           np.zeros(n_events, int),
-                           event_id * np.ones(n_events, int)]).T
+    logger.info(f"Number of EOG events detected: {n_events}")
+    eog_events = np.array(
+        [
+            eog_events + first_samp,
+            np.zeros(n_events, int),
+            event_id * np.ones(n_events, int),
+        ]
+    ).T
 
     return eog_events
 
 
 def _get_eog_channel_index(ch_name, inst):
     """Get EOG channel indices."""
-    _validate_type(ch_name, types=(None, str, list), item_name='ch_name')
+    _validate_type(ch_name, types=(None, str, list), item_name="ch_name")
 
     if ch_name is None:
-        eog_inds = pick_types(inst.info, meg=False, eeg=False, stim=False,
-                              eog=True, ecg=False, emg=False, ref_meg=False,
-                              exclude='bads')
+        eog_inds = pick_types(
+            inst.info,
+            meg=False,
+            eeg=False,
+            stim=False,
+            eog=True,
+            ecg=False,
+            emg=False,
+            ref_meg=False,
+            exclude="bads",
+        )
         if eog_inds.size == 0:
-            raise RuntimeError('No EOG channel(s) found')
+            raise RuntimeError("No EOG channel(s) found")
         ch_names = [inst.ch_names[i] for i in eog_inds]
     elif isinstance(ch_name, str):
         ch_names = [ch_name]
@@ -148,11 +212,12 @@ def _get_eog_channel_index(ch_name, inst):
 
     # ensure the specified channels are present in the data
     if ch_name is not None:
-        not_found = [ch_name for ch_name in ch_names
-                     if ch_name not in inst.ch_names]
+        not_found = [ch_name for ch_name in ch_names if ch_name not in inst.ch_names]
         if not_found:
-            raise ValueError(f'The specified EOG channel{_pl(not_found)} '
-                             f'cannot be found: {", ".join(not_found)}')
+            raise ValueError(
+                f"The specified EOG channel{_pl(not_found)} "
+                f'cannot be found: {", ".join(not_found)}'
+            )
 
         eog_inds = pick_channels(inst.ch_names, include=ch_names)
 
@@ -161,10 +226,24 @@ def _get_eog_channel_index(ch_name, inst):
 
 
 @verbose
-def create_eog_epochs(raw, ch_name=None, event_id=998, picks=None, tmin=-0.5,
-                      tmax=0.5, l_freq=1, h_freq=10, reject=None, flat=None,
-                      baseline=None, preload=True, reject_by_annotation=True,
-                      thresh=None, decim=1, verbose=None):
+def create_eog_epochs(
+    raw,
+    ch_name=None,
+    event_id=998,
+    picks=None,
+    tmin=-0.5,
+    tmax=0.5,
+    l_freq=1,
+    h_freq=10,
+    reject=None,
+    flat=None,
+    baseline=None,
+    preload=True,
+    reject_by_annotation=True,
+    thresh=None,
+    decim=1,
+    verbose=None,
+):
     """Conveniently generate epochs around EOG artifact events.
 
     %(create_eog_epochs)s
@@ -237,15 +316,30 @@ def create_eog_epochs(raw, ch_name=None, event_id=998, picks=None, tmin=-0.5,
     The resulting ``eog_epochs`` will have no filtering applied (i.e., have
     the same filter properties as the input ``raw`` instance).
     """
-    events = find_eog_events(raw, ch_name=ch_name, event_id=event_id,
-                             l_freq=l_freq, h_freq=h_freq,
-                             reject_by_annotation=reject_by_annotation,
-                             thresh=thresh)
+    events = find_eog_events(
+        raw,
+        ch_name=ch_name,
+        event_id=event_id,
+        l_freq=l_freq,
+        h_freq=h_freq,
+        reject_by_annotation=reject_by_annotation,
+        thresh=thresh,
+    )
 
     # create epochs around EOG events
-    eog_epochs = Epochs(raw, events=events, event_id=event_id, tmin=tmin,
-                        tmax=tmax, proj=False, reject=reject, flat=flat,
-                        picks=picks, baseline=baseline, preload=preload,
-                        reject_by_annotation=reject_by_annotation,
-                        decim=decim)
+    eog_epochs = Epochs(
+        raw,
+        events=events,
+        event_id=event_id,
+        tmin=tmin,
+        tmax=tmax,
+        proj=False,
+        reject=reject,
+        flat=flat,
+        picks=picks,
+        baseline=baseline,
+        preload=preload,
+        reject_by_annotation=reject_by_annotation,
+        decim=decim,
+    )
     return eog_epochs
