@@ -3,18 +3,22 @@
 #          Alexandre Gramfort <alexandre.gramfort@inria.fr>
 #
 # License: BSD-3-Clause
+# Copyright the MNE-Python contributors.
 
 import os.path as op
 
 import numpy as np
+from scipy import linalg
+from scipy.interpolate import interp1d
+from scipy.io import loadmat
 
+from ..._fiff.constants import FIFF
 from ...io import BaseRaw
-from ...io.constants import FIFF
 from ...utils import _validate_type, warn
-from ..nirs import source_detector_distances, _validate_nirs_info
+from ..nirs import _validate_nirs_info, source_detector_distances
 
 
-def beer_lambert_law(raw, ppf=6.):
+def beer_lambert_law(raw, ppf=6.0):
     r"""Convert NIRS optical density data to haemoglobin concentration.
 
     Parameters
@@ -29,29 +33,31 @@ def beer_lambert_law(raw, ppf=6.):
     raw : instance of Raw
         The modified raw instance.
     """
-    from scipy import linalg
     raw = raw.copy().load_data()
-    _validate_type(raw, BaseRaw, 'raw')
-    _validate_type(ppf, 'numeric', 'ppf')
+    _validate_type(raw, BaseRaw, "raw")
+    _validate_type(ppf, "numeric", "ppf")
     ppf = float(ppf)
-    picks = _validate_nirs_info(raw.info, fnirs='od', which='Beer-lambert')
+    picks = _validate_nirs_info(raw.info, fnirs="od", which="Beer-lambert")
     # This is the one place we *really* need the actual/accurate frequencies
-    freqs = np.array(
-        [raw.info['chs'][pick]['loc'][9] for pick in picks], float)
+    freqs = np.array([raw.info["chs"][pick]["loc"][9] for pick in picks], float)
     abs_coef = _load_absorption(freqs)
-    distances = source_detector_distances(raw.info, picks='all')
+    distances = source_detector_distances(raw.info, picks="all")
     bad = ~np.isfinite(distances[picks])
     bad |= distances[picks] <= 0
     if bad.any():
-        warn('Source-detector distances are zero on NaN, some resulting '
-             'concentrations will be zero. Consider setting a montage '
-             'with raw.set_montage.')
-    distances[picks[bad]] = 0.
+        warn(
+            "Source-detector distances are zero on NaN, some resulting "
+            "concentrations will be zero. Consider setting a montage "
+            "with raw.set_montage."
+        )
+    distances[picks[bad]] = 0.0
     if (distances[picks] > 0.1).any():
-        warn('Source-detector distances are greater than 10 cm. '
-             'Large distances will result in invalid data, and are '
-             'likely due to optode locations being stored in a '
-             ' unit other than meters.')
+        warn(
+            "Source-detector distances are greater than 10 cm. "
+            "Large distances will result in invalid data, and are "
+            "likely due to optode locations being stored in a "
+            " unit other than meters."
+        )
     rename = dict()
     for ii, jj in zip(picks[::2], picks[1::2]):
         EL = abs_coef * distances[ii] * ppf
@@ -60,17 +66,16 @@ def beer_lambert_law(raw, ppf=6.):
         raw._data[[ii, jj]] = iEL @ raw._data[[ii, jj]] * 1e-3
 
         # Update channel information
-        coil_dict = dict(hbo=FIFF.FIFFV_COIL_FNIRS_HBO,
-                         hbr=FIFF.FIFFV_COIL_FNIRS_HBR)
-        for ki, kind in zip((ii, jj), ('hbo', 'hbr')):
-            ch = raw.info['chs'][ki]
+        coil_dict = dict(hbo=FIFF.FIFFV_COIL_FNIRS_HBO, hbr=FIFF.FIFFV_COIL_FNIRS_HBR)
+        for ki, kind in zip((ii, jj), ("hbo", "hbr")):
+            ch = raw.info["chs"][ki]
             ch.update(coil_type=coil_dict[kind], unit=FIFF.FIFF_UNIT_MOL)
             new_name = f'{ch["ch_name"].split(" ")[0]} {kind}'
-            rename[ch['ch_name']] = new_name
+            rename[ch["ch_name"]] = new_name
     raw.rename_channels(rename)
 
     # Validate the format of data after transformation is valid
-    _validate_nirs_info(raw.info, fnirs='hb')
+    _validate_nirs_info(raw.info, fnirs="hb")
     return raw
 
 
@@ -85,18 +90,20 @@ def _load_absorption(freqs):
     #
     # Returns data as [[HbO2(freq1), Hb(freq1)],
     #                  [HbO2(freq2), Hb(freq2)]]
-    from scipy.io import loadmat
-    from scipy.interpolate import interp1d
+    extinction_fname = op.join(
+        op.dirname(__file__), "..", "..", "data", "extinction_coef.mat"
+    )
+    a = loadmat(extinction_fname)["extinct_coef"]
 
-    extinction_fname = op.join(op.dirname(__file__), '..', '..', 'data',
-                               'extinction_coef.mat')
-    a = loadmat(extinction_fname)['extinct_coef']
+    interp_hbo = interp1d(a[:, 0], a[:, 1], kind="linear")
+    interp_hb = interp1d(a[:, 0], a[:, 2], kind="linear")
 
-    interp_hbo = interp1d(a[:, 0], a[:, 1], kind='linear')
-    interp_hb = interp1d(a[:, 0], a[:, 2], kind='linear')
-
-    ext_coef = np.array([[interp_hbo(freqs[0]), interp_hb(freqs[0])],
-                         [interp_hbo(freqs[1]), interp_hb(freqs[1])]])
+    ext_coef = np.array(
+        [
+            [interp_hbo(freqs[0]), interp_hb(freqs[0])],
+            [interp_hbo(freqs[1]), interp_hb(freqs[1])],
+        ]
+    )
     abs_coef = ext_coef * 0.2303
 
     return abs_coef
