@@ -3,12 +3,13 @@
 #          Alexandre Gramfort <alexandre.gramfort@inria.fr>
 #
 # License: BSD-3-Clause
+# Copyright the MNE-Python contributors.
 
 import numpy as np
 
+from ..._fiff.constants import FIFF
 from ...io import BaseRaw
-from ...io.constants import FIFF
-from ...utils import _validate_type, warn, verbose
+from ...utils import _validate_type, verbose, warn
 from ..nirs import _validate_nirs_info
 
 
@@ -28,8 +29,8 @@ def optical_density(raw, *, verbose=None):
         The modified raw instance.
     """
     raw = raw.copy().load_data()
-    _validate_type(raw, BaseRaw, 'raw')
-    picks = _validate_nirs_info(raw.info, fnirs='cw_amplitude')
+    _validate_type(raw, BaseRaw, "raw")
+    picks = _validate_nirs_info(raw.info, fnirs="cw_amplitude")
 
     # The devices measure light intensity. Negative light intensities should
     # not occur. If they do it is likely due to hardware or movement issues.
@@ -50,6 +51,6 @@ def optical_density(raw, *, verbose=None):
         raw._data[pi] /= data_mean
         np.log(raw._data[pi], out=raw._data[pi])
         raw._data[pi] *= -1
-        raw.info['chs'][pi]['coil_type'] = FIFF.FIFFV_COIL_FNIRS_OD
+        raw.info["chs"][pi]["coil_type"] = FIFF.FIFFV_COIL_FNIRS_OD
 
     return raw
