@@ -3,37 +3,42 @@
 #          Alexandre Gramfort <alexandre.gramfort@inria.fr>
 #
 # License: BSD-3-Clause
+# Copyright the MNE-Python contributors.
 
-import os.path as op
-
-import pytest
 import numpy as np
+import pytest
 from numpy.testing import assert_allclose, assert_array_less
 
+from mne.datasets import testing
 from mne.datasets.testing import data_path
 from mne.io import read_raw_nirx
-from mne.preprocessing.nirs import optical_density, scalp_coupling_index,\
-    beer_lambert_law
-from mne.datasets import testing
+from mne.preprocessing.nirs import (
+    beer_lambert_law,
+    optical_density,
+    scalp_coupling_index,
+)
 
-fname_nirx_15_0 = op.join(data_path(download=False),
-                          'NIRx', 'nirscout', 'nirx_15_0_recording')
-fname_nirx_15_2 = op.join(data_path(download=False),
-                          'NIRx', 'nirscout', 'nirx_15_2_recording')
-fname_nirx_15_2_short = op.join(data_path(download=False),
-                                'NIRx', 'nirscout',
-                                'nirx_15_2_recording_w_short')
+fname_nirx_15_0 = (
+    data_path(download=False) / "NIRx" / "nirscout" / "nirx_15_0_recording"
+)
+fname_nirx_15_2 = (
+    data_path(download=False) / "NIRx" / "nirscout" / "nirx_15_2_recording"
+)
+fname_nirx_15_2_short = (
+    data_path(download=False) / "NIRx" / "nirscout" / "nirx_15_2_recording_w_short"
+)
 
 
 @testing.requires_testing_data
-@pytest.mark.parametrize('fname', ([fname_nirx_15_2_short, fname_nirx_15_2,
-                                    fname_nirx_15_0]))
-@pytest.mark.parametrize('fmt', ('nirx', 'fif'))
+@pytest.mark.parametrize(
+    "fname", ([fname_nirx_15_2_short, fname_nirx_15_2, fname_nirx_15_0])
+)
+@pytest.mark.parametrize("fmt", ("nirx", "fif"))
 def test_scalp_coupling_index(fname, fmt, tmp_path):
     """Test converting NIRX files."""
-    assert fmt in ('nirx', 'fif')
+    assert fmt in ("nirx", "fif")
     raw = read_raw_nirx(fname)
-    with pytest.raises(RuntimeError, match='Scalp'):
+    with pytest.raises(RuntimeError, match="Scalp"):
         scalp_coupling_index(raw)
 
     raw = optical_density(raw)
@@ -59,10 +64,10 @@ def test_scalp_coupling_index(fname, fmt, tmp_path):
     raw._data[6] = new_data
     raw._data[7] = rng.rand(raw._data[0].shape[0])
     # Set next channel to have zero std
-    raw._data[8] = 0.
-    raw._data[9] = 1.
-    raw._data[10] = 2.
-    raw._data[11] = 3.
+    raw._data[8] = 0.0
+    raw._data[9] = 1.0
+    raw._data[10] = 2.0
+    raw._data[11] = 3.0
     # Check values
     sci = scalp_coupling_index(raw)
     assert_allclose(sci[0:6], [1, 1, 1, 1, -1, -1], atol=0.01)
@@ -72,5 +77,5 @@ def test_scalp_coupling_index(fname, fmt, tmp_path):
 
     # Ensure function errors if wrong type is passed in
     raw = beer_lambert_law(raw, ppf=6)
-    with pytest.raises(RuntimeError, match='Scalp'):
+    with pytest.raises(RuntimeError, match="Scalp"):
         scalp_coupling_index(raw)
