@@ -1,20 +1,22 @@
-import os.path as op
+# License: BSD-3-Clause
+# Copyright the MNE-Python contributors.
+from pathlib import Path
 
 from mne import Annotations
 from mne.io import read_raw_fif
 from mne.preprocessing.eog import find_eog_events
 
-data_path = op.join(op.dirname(__file__), '..', '..', 'io', 'tests', 'data')
-raw_fname = op.join(data_path, 'test_raw.fif')
-event_fname = op.join(data_path, 'test-eve.fif')
-proj_fname = op.join(data_path, 'test-proj.fif')
+data_path = Path(__file__).parent.parent.parent / "io" / "tests" / "data"
+raw_fname = data_path / "test_raw.fif"
+event_fname = data_path / "test-eve.fif"
+proj_fname = data_path / "test-proj.fif"
 
 
 def test_find_eog():
     """Test find EOG peaks."""
-    ch_name = 'EOG 061'
+    ch_name = "EOG 061"
     raw = read_raw_fif(raw_fname)
-    raw.set_annotations(Annotations([14, 21], [1, 1], 'BAD_blink'))
+    raw.set_annotations(Annotations([14, 21], [1, 1], "BAD_blink"))
 
     events = find_eog_events(raw, ch_name=ch_name)
     assert len(events) == 4
@@ -31,5 +33,5 @@ def test_find_eog():
     events = find_eog_events(raw, ch_name=None)
     assert len(events) == 4
 
-    events = find_eog_events(raw, ch_name=['EEG 060', 'EOG 061'])
+    events = find_eog_events(raw, ch_name=["EEG 060", "EOG 061"])
     assert len(events) == 4
