@@ -1,19 +1,18 @@
 # Authors: Denis A. Engemann <denis.engemann@gmail.com>
 #
-# License: BSD (3-clause)
+# License: BSD-3-Clause
+# Copyright the MNE-Python contributors.
 
 # Parts of this code are taken from scikit-learn
 
-import pytest
-
 import numpy as np
+import pytest
 from numpy.testing import assert_almost_equal
-
-from scipy import stats
-from scipy import linalg
+from scipy import linalg, stats
 
 from mne.preprocessing.infomax_ import infomax
-from mne.utils import requires_sklearn, run_tests_if_main
+
+pytest.importorskip("sklearn")
 
 
 def center_and_norm(x, axis=-1):
@@ -32,7 +31,6 @@ def center_and_norm(x, axis=-1):
     x /= x.std(axis=0)
 
 
-@requires_sklearn
 def test_infomax_blowup():
     """Test the infomax algorithm blowup condition."""
     # scipy.stats uses the global RNG:
@@ -47,8 +45,9 @@ def test_infomax_blowup():
 
     # Mixing angle
     phi = 0.6
-    mixing = np.array([[np.cos(phi),  np.sin(phi)],  # noqa: E241
-                       [np.sin(phi), -np.cos(phi)]])
+    mixing = np.array(
+        [[np.cos(phi), np.sin(phi)], [np.sin(phi), -np.cos(phi)]]  # noqa: E241
+    )
     m = np.dot(mixing, s)
 
     center_and_norm(m)
@@ -71,7 +70,6 @@ def test_infomax_blowup():
     assert_almost_equal(np.dot(s2_, s2) / n_samples, 1, decimal=2)
 
 
-@requires_sklearn
 def test_infomax_simple():
     """Test the infomax algorithm on very simple data."""
     rng = np.random.RandomState(0)
@@ -87,8 +85,9 @@ def test_infomax_simple():
 
     # Mixing angle
     phi = 0.6
-    mixing = np.array([[np.cos(phi),  np.sin(phi)],  # noqa: E241
-                       [np.sin(phi), -np.cos(phi)]])
+    mixing = np.array(
+        [[np.cos(phi), np.sin(phi)], [np.sin(phi), -np.cos(phi)]]  # noqa: E241
+    )
     for add_noise in (False, True):
         m = np.dot(mixing, s)
         if add_noise:
@@ -131,7 +130,6 @@ def test_infomax_weights_ini():
     assert_almost_equal(w2, weights)
 
 
-@requires_sklearn
 def test_non_square_infomax():
     """Test non-square infomax."""
     rng = np.random.RandomState(0)
@@ -185,8 +183,7 @@ def test_infomax_n_iter(return_n_iter):
     """Test the return_n_iter kwarg."""
     X = np.random.random((3, 100))
     max_iter = 1
-    r = infomax(X, max_iter=max_iter, extended=True,
-                return_n_iter=return_n_iter)
+    r = infomax(X, max_iter=max_iter, extended=True, return_n_iter=return_n_iter)
 
     if return_n_iter:
         assert isinstance(r, tuple)
@@ -197,8 +194,5 @@ def test_infomax_n_iter(return_n_iter):
 
 def _get_pca(rng=None):
     from sklearn.decomposition import PCA
-    return PCA(n_components=2, whiten=True, svd_solver='randomized',
-               random_state=rng)
 
-
-run_tests_if_main()
+    return PCA(n_components=2, whiten=True, svd_solver="randomized", random_state=rng)
