@@ -1,6 +1,8 @@
-from numpy.testing import assert_array_equal, assert_equal
-import pytest
+# License: BSD-3-Clause
+# Copyright the MNE-Python contributors.
 import numpy as np
+import pytest
+from numpy.testing import assert_array_equal, assert_equal
 
 from mne.preprocessing import peak_finder
 
@@ -11,8 +13,8 @@ def test_peak_finder():
     rng = np.random.RandomState(42)
     peak_inds, peak_mags = peak_finder(rng.randn(20))
 
-    assert_equal(peak_inds.dtype, np.dtype('int64'))
-    assert_equal(peak_mags.dtype, np.dtype('float64'))
+    assert_equal(peak_inds.dtype, np.dtype("int64"))
+    assert_equal(peak_mags.dtype, np.dtype("float64"))
 
     # check for empty array as created in the #5025
     with pytest.raises(ValueError):
@@ -25,14 +27,14 @@ def test_peak_finder():
     # check for monotonic function
     peak_inds, peak_mags = peak_finder(np.arange(1, 2, 0.05))
 
-    assert_equal(peak_inds.dtype, np.dtype('int64'))
-    assert_equal(peak_mags.dtype, np.dtype('float64'))
+    assert_equal(peak_inds.dtype, np.dtype("int64"))
+    assert_equal(peak_mags.dtype, np.dtype("float64"))
 
     # check for no peaks
     peak_inds, peak_mags = peak_finder(np.zeros(20))
 
-    assert_equal(peak_inds.dtype, np.dtype('int64'))
-    assert_equal(peak_mags.dtype, np.dtype('float64'))
+    assert_equal(peak_inds.dtype, np.dtype("int64"))
+    assert_equal(peak_mags.dtype, np.dtype("float64"))
 
     # check values
     peak_inds, peak_mags = peak_finder([0, 2, 5, 0, 6, -1])
